<?php

namespace App\DataTables;

use App\Models\COA\SubAccount;
use Illuminate\Database\Eloquent\Builder as QueryBuilder;
use Yajra\DataTables\EloquentDataTable;
use Yajra\DataTables\Html\Builder as HtmlBuilder;
use Yajra\DataTables\Html\Button;
use Yajra\DataTables\Html\Column;
use Yajra\DataTables\Html\Editor\Editor;
use Yajra\DataTables\Html\Editor\Fields;
use Yajra\DataTables\Services\DataTable;

class CoaDataTable extends DataTable
{
    /**
     * Build the DataTable class.
     *
     * @param QueryBuilder $query Results from query() method.
     */
    public function dataTable(QueryBuilder $query): EloquentDataTable
    {
        $myValue = '';

        return (new EloquentDataTable($query))

            ->addColumn('code', function ($query) {

                return $query->code;
            })
            ->addColumn('name', function ($query) {

                return $query->name;
            })
            ->addColumn('head', function ($query) {

                return $query->parent->name;
            })


            ->addColumn('action', function ($query) {
                $viewBtn = view('icons.view')->render();
                return "<a href='" . $query->reportLink . "'>$viewBtn</a>";
            })
            ->setRowId('id');
    }

    /**
     * Get the query source of dataTable.
     */
    public function query(SubAccount $model): QueryBuilder
    {
        return $model->newQuery()->orderBy('code', 'asc');

    }

    /**
     * Optional method if you want to use the html builder.
     */
    public function html(): HtmlBuilder
    {
        return $this->builder()
            ->setTableId('coa-table')
            ->columns([
                'code' => ['title' => 'Code'],
                'name' => ['title' => 'Name'],
                'head' => ['title' => 'Account Head'],
                'action' => ['title' => '']
            ])

            ->minifiedAjax()
            //->dom('Bfrtip')
            ->orderBy(1)
            ->selectStyleSingle()
            ->buttons([
                Button::make('excel'),
                Button::make('csv'),
                Button::make('pdf'),
                Button::make('print'),
                Button::make('reset'),
                Button::make('reload')
            ]);
    }

    /**
     * Get the dataTable columns definition.
     */
    public function getColumns(): array
    {


        return [


            'code',
            'name',
            'head',
            'action',



        ];
    }

    /**
     * Get the filename for export.
     */
    protected function filename(): string
    {
        return 'CreditNotes_' . date('YmdHis');
    }
}
