<?php



namespace App\DataTables\FixedAssets;



use App\Models\FixedAsset;

use App\Models\Order;

use Illuminate\Database\Eloquent\Builder as QueryBuilder;

use Yajra\DataTables\EloquentDataTable;

use Yajra\DataTables\Html\Builder as HtmlBuilder;

use Yajra\DataTables\Html\Button;

use Yajra\DataTables\Html\Column;

use Yajra\DataTables\Html\Editor\Editor;

use Yajra\DataTables\Html\Editor\Fields;

use Yajra\DataTables\Services\DataTable;

use DateTime;

use Carbon\Carbon;

use App\Facades\Company;



class FixedAssetDataTable extends DataTable

{

    /**

     * Build the DataTable class.

     *

     * @param QueryBuilder $query Results from query() method.

     */

    public function dataTable(QueryBuilder $query): EloquentDataTable

    {

        return (new EloquentDataTable($query))

            ->addColumn('month', function ($query) {

                return date('M', strtotime($query->purchasedate));

            })

            ->filterColumn('month', function ($query, $keyword) {

                // Parse the month name to a date format

                $monthDate = date_parse($keyword);



                if ($monthDate['error_count'] === 0 && $monthDate['warning_count'] === 0) {

                    $query->whereRaw("MONTH(purchasedate) = ?", [$monthDate['month']]);

                }

            })



            ->addColumn('purchasedate', function ($query) {

                return date('d M y', strtotime($query->purchasedate));

            })

            ->addColumn('purchasedate', function ($query) {

                return date('d M y', strtotime($query->purchasedate));

            })



            ->addColumn('totalAmount', function ($query) {



                $viewTotal = $query->getTotalAmountSumAttribute();





                return $query->company ? $query->company->companyCurrency . '' . number_format($viewTotal, 2) : '';



            })

            ->addColumn('action', function ($query) {

                $viewBtn = view('icons.view')->render();

                return "<a href='" . route('fixed-assets.show', $query->id) . "'>$viewBtn</a>";



            })



            ->setRowId('id');

    }



    /**

     * Get the query source of dataTable.

     */

    public function query(FixedAsset $model): QueryBuilder

    {

        //return $model->newQuery()->latest();



        return $model->newQuery()

            ->where(function ($query) {

                $fromDate = $this->request->input('fromdate');

                $toDate = $this->request->input('todate');



                if ($fromDate) {

                    $fromDate = Carbon::parse($fromDate)->startOfDay();

                    $query->where('purchasedate', '>=', $fromDate);

                }



                if ($toDate) {

                    $toDate = Carbon::parse($toDate)->endOfDay();

                    $query->where('purchasedate', '<=', $toDate);

                }

            })

            ->latest();







    }



    /**

     * Optional method if you want to use the html builder.

     */

    public function html(): HtmlBuilder

    {

        return $this->builder()

            ->setTableId('orders-table')

            ->columns([



                'month' => ['title' => 'Month'],

                'ref' => ['title' => 'Reference'],



                'purchasedate' => ['title' => 'Order Date'],



                'totalAmount' => [

                    'title' => 'Amount

                '

                ],

                'action' => ['title' => ''],



            ])

            ->minifiedAjax('', null, request()->only(['fromdate', 'todate']))

            //->dom('Bfrtip')

            ->orderBy(1)

            ->selectStyleSingle()

            ->buttons([

                Button::make('excel'),

                Button::make('csv'),

                Button::make('pdf'),

                Button::make('print'),

                Button::make('reset'),

                Button::make('reload')

            ]);

    }



    /**

     * Get the dataTable columns definition.

     */







    public function getColumns(): array

    {

        return [





            'month',

            'ref',



            'purchasedate',



            'totalAmount',

            'action',







        ];

    }



    /**

     * Get the filename for export.

     */

    protected function filename(): string

    {

        return 'Orders_' . date('YmdHis');

    }

}

