<?php

namespace App\DataTables\Purchase;

use App\Models\PurchaseInvoice;
use Illuminate\Database\Eloquent\Builder as QueryBuilder;
use Yajra\DataTables\EloquentDataTable;
use Yajra\DataTables\Html\Builder as HtmlBuilder;
use Yajra\DataTables\Html\Button;
use Yajra\DataTables\Html\Column;
use Yajra\DataTables\Html\Editor\Editor;
use Yajra\DataTables\Html\Editor\Fields;
use Yajra\DataTables\Services\DataTable;

class DebitNoteDataTable extends DataTable
{
    /**
     * Build the DataTable class.
     *
     * @param QueryBuilder $query Results from query() method.
     */
    public function dataTable(QueryBuilder $query): EloquentDataTable
    {
        $myValue = '';

        return (new EloquentDataTable($query))

            ->addColumn('saleorder_id', function ($query) {
                $myValue = $query->company ? $query->company->companyPrefix : '';
                return 'D' . $myValue . '' . $query->saleorder_id . '-' . $query->invoice_serial;
            })
            ->filterColumn('saleorder_id', function ($query, $keyword) {

                $company = \App\Models\Company::select('companyPrefix')->where('id', auth()->user()->company_id)->first();
                $myValue = $company->companyPrefix;
                $keyword = str_replace($myValue, '', $keyword);
                $query->orWhere('saleorder_id', 'like', '%' . $keyword . '%');

            })
            ->addColumn('vendor', function ($query) {
                return $query->vendor->company;
            })
            ->addColumn('action', function ($query) {
                $viewBtn = view('icons.view')->render();
                return "<a href='" . route('debit-notes.show', $query->id) . "'>$viewBtn</a>";
            })->addColumn('totalAmount', function ($query) {
            $viewTotal = $query->getTotalAmountSumAttribute() + $query->getTotalChargeSumAttribute();
            return $query->company ? $query->company->companyCurrency . '' . number_format($viewTotal, 2) : '';
        })->setRowId('id');
    }

    /**
     * Get the query source of dataTable.
     */
    public function query(PurchaseInvoice $model): QueryBuilder
    {
        return $model->newQuery()->where('order_type', 2)->latest();

    }

    /**
     * Optional method if you want to use the html builder.
     */
    public function html(): HtmlBuilder
    {
        return $this->builder()
            ->setTableId('invoices-table')
            ->columns([
                'saleorder_id' => ['title' => 'Credit Note #'],
                'vendor' => ['title' => 'Vendor'],
                'shippingContact' => ['title' => 'Shipping Contact'],
                //'orderdate' => ['title' => 'Order Date'],
                'totalAmount' => ['title' => 'Amount'],
                'action' => ['title' => '']
            ])

            ->minifiedAjax()
            //->dom('Bfrtip')
            ->orderBy(1)
            ->selectStyleSingle()
            ->buttons([
                Button::make('excel'),
                Button::make('csv'),
                Button::make('pdf'),
                Button::make('print'),
                Button::make('reset'),
                Button::make('reload')
            ]);
    }

    /**
     * Get the dataTable columns definition.
     */
    public function getColumns(): array
    {


        return [
            'saleorder_id',
            'customer',
            'billingPerson',
            'totalAmount',
            'action',
        ];
    }

    /**
     * Get the filename for export.
     */
    protected function filename(): string
    {
        return 'DebitNotes_' . date('YmdHis');
    }
}
