<?php

namespace App\DataTables;

use App\Models\Quotation;
use Illuminate\Database\Eloquent\Builder as QueryBuilder;
use Yajra\DataTables\EloquentDataTable;
use Yajra\DataTables\Html\Builder as HtmlBuilder;
use Yajra\DataTables\Html\Button;
use Yajra\DataTables\Html\Column;
use Yajra\DataTables\Html\Editor\Editor;
use Yajra\DataTables\Html\Editor\Fields;
use Yajra\DataTables\Services\DataTable;

class QuotesDataTable extends DataTable
{
    /**
     * Build the DataTable class.
     *
     * @param QueryBuilder $query Results from query() method.
     */
    public function dataTable(QueryBuilder $query): EloquentDataTable
    {
        return (new EloquentDataTable($query))->addColumn('customer', function ($query) {
            return $query->customer->company;
        })->addColumn('action', function ($query) {
            //$viewBtn = view('icons.view')->render();
            return "<a href='" . route('quotes.show', $query->id) . "'>view</a>";
        })->addColumn('totalAmount', function ($query) {
            $viewTotal = $query->getTotalAmountSumAttribute() + $query->getTotalChargeSumAttribute();
            return $query->company ? $query->company->companyCurrency . '' . number_format($viewTotal, 2) : '';
        })->setRowId('id');
    }

    /**
     * Get the query source of dataTable.
     */
    public function query(Quotation $model): QueryBuilder
    {
        return $model->newQuery()->latest();

    }

    /**
     * Optional method if you want to use the html builder.
     */
    public function html(): HtmlBuilder
    {
        return $this->builder()
            ->setTableId('quotes-table')
            ->columns($this->getColumns())
            ->minifiedAjax()
            //->dom('Bfrtip')
            ->orderBy(1)
            ->selectStyleSingle()
            ->buttons([
                Button::make('excel'),
                Button::make('csv'),
                Button::make('pdf'),
                Button::make('print'),
                Button::make('reset'),
                Button::make('reload')
            ]);
    }

    /**
     * Get the dataTable columns definition.
     */
    public function getColumns(): array
    {
        return [


            Column::make('quoteid'),
            Column::make('customer'),
            Column::make('ref'),
            Column::make('billingPerson'),
            Column::make('totalAmount'),
            Column::computed('action')
                ->exportable(false)
                ->printable(false)
                ->width(60)
                ->addClass('text-center'),
        ];
    }

    /**
     * Get the filename for export.
     */
    protected function filename(): string
    {
        return 'Quotes_' . date('YmdHis');
    }
}
