<?php

namespace App\DataTables\Reports\Purchase;

use App\Models\PurchaseInvoice;
use Illuminate\Database\Eloquent\Builder as QueryBuilder;
use Yajra\DataTables\EloquentDataTable;
use Yajra\DataTables\Html\Builder as HtmlBuilder;
use Yajra\DataTables\Html\Button;
use Yajra\DataTables\Html\Column;
use Yajra\DataTables\Html\Editor\Editor;
use Yajra\DataTables\Html\Editor\Fields;
use Yajra\DataTables\Services\DataTable;
use DateTime;
use Carbon\Carbon;
use App\Facades\Company;

class CoaPurchaseCreditCardReport extends DataTable
{

    public $counter = 0;
    public $closingBalance = 0;
    public $openingBalance = 0;
    public $debit = 0;
    public $credit = 0;
    /**
     * Build the DataTable class.
     *
     * @param QueryBuilder $query Results from query() method.
     */
    public function dataTable(QueryBuilder $query): EloquentDataTable
    {

        return (new EloquentDataTable($query))


            ->addColumn('ref', function ($query) {
                $pfc = '';
                if ($query->order_type == 2) {
                    $pfc = 'DN';
                }
                $alphabet = array ('', 'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z');

                  return $query->company ? $pfc . $query->company->companyPrefix . '' . $query->saleorder_id . '' . $alphabet[$query->invoice_serial] . '-' . $query->purchaseGroup : '';
            })
            ->addColumn('invoicedate', function ($query) {
                return date('d M y', strtotime($query->invoicedate));
            })
            ->addColumn('customer', function ($query) {
                $items = '';
                foreach ($query->invoiceItems as $key => $item) {
                    $items .= '(' . ++$key . ') ' . $item->item->description . ' ~ (' . $query->company->companyCurrency . '' . $item->item->price . 'x' . $item->item->quantity . ') ';
                }
                return $query->customer ? $query->customer->company . ', ' . $items : '';
            })
            ->addColumn('creditAmount', function ($query) {

                if ($query->order_type == 2) {
                    $viewTotal = $query->getTotalCreditCardSumAttribute();
                } else {
                    $viewTotal = 0;
                }
                $this->credit = $viewTotal;
                return $query->company ? $query->company->companyCurrency . '' . number_format($viewTotal, 2) : '';
            })
            ->addColumn('debitAmount', function ($query) {
                if ($query->order_type == 1) {
                    $viewTotal = $query->getTotalCreditCardSumAttribute();
                } else {
                    $viewTotal = 0;
                }
                $this->debit = $viewTotal;
                return $query->company ? $query->company->companyCurrency . '' . number_format($viewTotal, 2) : '';
            })


            ->addColumn('balance', function ($query) {
                $this->counter++;

                if ($this->counter == 1 && $this->request->input('fromdate')) {

                    $credit = PurchaseInvoice::where('order_type', 1)
                        ->where('invoicedate', '<', $this->request->input('fromdate'))
                        ->get()
                        ->sum(function ($inv) {
                            return $inv->invoiceItems->sum(function ($orderItem) {
                                return $orderItem->quantity * $orderItem->price;
                            });
                        });

                    $debit = PurchaseInvoice::where('order_type', 2)
                        ->where('invoicedate', '<', $this->request->input('fromdate'))
                        ->get()
                        ->sum(function ($inv) {
                            return $inv->invoiceItems->sum(function ($orderItem) {
                                return $orderItem->quantity * $orderItem->price;
                            });
                        });

                    // $this->openingBalance = $credit - $debit;
                    // $this->closingBalance = $credit - $debit;
                                  $this->openingBalance = $credit - $debit;
                        $this->closingBalance = $this->openingBalance;

                }

                $this->closingBalance = $this->closingBalance + $this->credit - $this->debit;

                return $query->company ? $query->company->companyCurrency . '' . number_format($this->closingBalance, 2) : '';

            })

            // ->addColumn('opening', function ($query) {
            //     if ($this->counter == 1) {

            //         return $query->company ? $query->company->companyCurrency . '' . number_format($this->openingBalance, 2) : '';
            //     } else {
            //         return '';
            //     }
            // })
            ->setRowId('id');

    }

    /**
     * Get the query source of dataTable.
     */
    public function query(PurchaseInvoice $model): QueryBuilder
    {
        //return $model->newQuery()->latest();

        return $model->newQuery()
            ->whereHas('invoiceCreditCard', function ($query) {
                $query->where('charge_id', '>', 0);
            })
            ->where(function ($query) {
                $fromDate = $this->request->input('fromdate');
                $toDate = $this->request->input('todate');

                if ($fromDate) {
                    $fromDate = Carbon::parse($fromDate)->startOfDay();
                    $query->where('invoicedate', '>=', $fromDate);
                }

                if ($toDate) {
                    $toDate = Carbon::parse($toDate)->endOfDay();
                    $query->where('invoicedate', '<=', $toDate);
                }
            })
            ->orderBy('invoicedate', 'asc');
        //  ->latest();



    }

    /**
     * Optional method if you want to use the html builder.
     */
    public function html(): HtmlBuilder
    {
        return $this->builder()
            ->setTableId('orders-table')
            ->columns([

                'ref' => ['title' => 'PO Invoice'],
                // 'opening' => ['title' => 'Opening Balance'],
                'customer' => ['title' => 'Description'],
                'invoicedate' => ['title' => 'Date'],
                'debitAmount' => ['title' => 'Debit'],
                'creditAmount' => ['title' => 'Credit'],
                'balance' => ['title' => 'Balance'],

            ])
            ->minifiedAjax('', null, request()->only(['fromdate', 'todate', 'stateid']))
            //->dom('Bfrtip')
            ->orderBy(1)
            ->selectStyleSingle()
            ->buttons([
                Button::make('excel'),
                Button::make('csv'),
                Button::make('pdf'),
                Button::make('print'),
                Button::make('reset'),
                Button::make('reload')
            ]);
    }

    /**
     * Get the dataTable columns definition.
     */



    public function getColumns(): array
    {
        return [


            'ref',
            'customer',
            'invoicedate',
            'debitAmount',
            'creditAmount',



        ];
    }

    /**
     * Get the filename for export.
     */
    protected function filename(): string
    {
        return 'Orders_' . date('YmdHis');
    }
}
