<?php


namespace App\DataTables\Reports\Purchase;


use App\Models\Order;
use Illuminate\Database\Eloquent\Builder as QueryBuilder;
use Yajra\DataTables\EloquentDataTable;
use Yajra\DataTables\Html\Builder as HtmlBuilder;
use Yajra\DataTables\Html\Button;
use Yajra\DataTables\Html\Column;
use Yajra\DataTables\Html\Editor\Editor;
use Yajra\DataTables\Html\Editor\Fields;
use Yajra\DataTables\Services\DataTable;
use DateTime;
use Carbon\Carbon;
use App\Facades\Company;

class PendingPurchaseReport extends DataTable
{
    /**
     * Build the DataTable class.
     *
     * @param QueryBuilder $query Results from query() method.
     */
    public function dataTable(QueryBuilder $query): EloquentDataTable
    {
        $counter = 0;
        return (new EloquentDataTable($query))
            ->addIndexColumn()

            ->addColumn('serial_no', function () use (&$counter) {
                // Increment the counter for each row
                return ++$counter;
            })


          

            ->addColumn('salesRep', function ($query) {
                return $query->saleRep ? $query->saleRep->name : '';
            })
            ->filterColumn('salesRep', function ($query, $keyword) {
                $query->whereHas('saleRep', function ($subquery) use ($keyword) {
                    $subquery->where('name', 'like', "%{$keyword}%");
                });
            })

            ->addColumn('orderdate', function ($query) {
                return date('d M y', strtotime($query->orderdate));
            })
            ->addColumn('orderdate', function ($query) {
                return date('d M y', strtotime($query->orderdate));
            })
            ->addColumn('customer', function ($query) {
                return $query->customer ? $query->customer->company : '';
            })->filterColumn('customer', function ($query, $keyword) {
                $query->whereHas('customer', function ($subquery) use ($keyword) {
                    $subquery->where('company', 'like', "%{$keyword}%");
                });
            })->addColumn('saleorder_id', function ($query) {
                return $query->company ? $query->company->companyPrefix . '' . $query->saleorder_id : '';
            })->filterColumn('saleorder_id', function ($query, $keyword) {
                $query->orWhere('saleorder_id', 'like', '%' . $keyword . '%');
            })
            ->addColumn('totalAmount', function ($query) {
                $viewTotal = $query->getTotalAmountSumAttribute() + $query->getTotalChargeSumAttribute();
                return $query->company ? $query->company->companyCurrency . '' . number_format($viewTotal, 2) : '';
            })
            ->setRowId('id');
    }

    /**
     * Get the query source of dataTable.
     */
    public function query(Order $model): QueryBuilder
    {
        //return $model->newQuery()->latest();

        return $model->newQuery()
            ->where('status_id', 2)
            ->where(function ($query) {
                $fromDate = $this->request->input('fromdate');
                $toDate = $this->request->input('todate');

                if ($fromDate) {
                    $fromDate = Carbon::parse($fromDate)->startOfDay();
                    $query->where('orderdate', '>=', $fromDate);
                }

                if ($toDate) {
                    $toDate = Carbon::parse($toDate)->endOfDay();
                    $query->where('orderdate', '<=', $toDate);
                }
            })
           ->whereDoesntHave('purchases') 
            ->latest();



    }

    /**
     * Optional method if you want to use the html builder.
     */
    public function html(): HtmlBuilder
    {
        return $this->builder()
            ->setTableId('orders-table')
            ->columns([
                'serial_no' => ['title' => '#'],
            
                'salesRep' => ['title' => 'Sales Rep'],

                'orderdate' => ['title' => 'SO Date'],
                'saleorder_id' => ['title' => 'SO#'],
                'customer' => ['title' => 'Customer Name'],
                'ref' => ['title' => 'PO Reference'],
                'totalAmount' => ['title' => 'Amount'],


            ])
            ->minifiedAjax('', null, request()->only(['fromdate', 'todate']))
            //->dom('Bfrtip')
            ->orderBy(1)
            ->selectStyleSingle()
            ->buttons([
                Button::make('excel'),
                Button::make('csv'),
                Button::make('pdf'),
                Button::make('print'),
                Button::make('reset'),
                Button::make('reload')
            ]);
    }

    /**
     * Get the dataTable columns definition.
     */



    public function getColumns(): array
    {
        return [

            'serial_no',
            'salesRep',
            'month',
            'ref',
            'customer',
            'orderdate',
            'saleorder_id',
            'totalAmount',



        ];
    }

    /**
     * Get the filename for export.
     */
    protected function filename(): string
    {
        return 'Orders_' . date('YmdHis');
    }
}
