<?php


namespace App\DataTables\Reports\Purchase;

use App\Models\Purchase;
use Illuminate\Database\Eloquent\Builder as QueryBuilder;
use Yajra\DataTables\EloquentDataTable;
use Yajra\DataTables\Html\Builder as HtmlBuilder;
use Yajra\DataTables\Html\Button;
use Yajra\DataTables\Html\Column;
use Yajra\DataTables\Html\Editor\Editor;
use Yajra\DataTables\Html\Editor\Fields;
use Yajra\DataTables\Services\DataTable;
use DateTime;
use Carbon\Carbon;
use App\Facades\Company;

class PurchaseReport extends DataTable
{
    /**
     * Build the DataTable class.
     *
     * @param QueryBuilder $query Results from query() method.
     */
    public function dataTable(QueryBuilder $query): EloquentDataTable
    {
        return (new EloquentDataTable($query))
            ->addColumn('vendor', function ($query) {
                return $query->vendor ? $query->vendor->company : '';
            })
            ->filterColumn('vendor', function ($query, $keyword) {
                $query->whereHas('vendor', function ($subquery) use ($keyword) {
                    $subquery->where('name', 'like', "%{$keyword}%");
                });
            })

        
            ->addColumn('orderdate', function ($query) {
                return date('d M y', strtotime($query->created_at));
            })
            ->addColumn('orderdate', function ($query) {
                return date('d M y', strtotime($query->created_at));
            })
            ->addColumn('customer', function ($query) {
                return $query->customer ? $query->customer->company : '';
            })->filterColumn('customer', function ($query, $keyword) {
            $query->whereHas('customer', function ($subquery) use ($keyword) {
                $subquery->where('company', 'like', "%{$keyword}%");
            });
        })->addColumn('saleorder_id', function ($query) {
            $alphabet =
                array('', 'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z');

            return $query->company ? $query->company->companyPrefix . '' . $query->saleorder_id . $alphabet[$query->purchaseGroup] : '';
        })->filterColumn('saleorder_id', function ($query, $keyword) {
            $query->orWhere('saleorder_id', 'like', '%' . $keyword . '%');
        })->addColumn('totalAmount', function ($query) {
            $viewTotal = $query->getTotalAmountSumAttribute() + $query->getTotalChargeSumAttribute();
            return $query->company ? $query->company->companyCurrency . '' . number_format($viewTotal, 2) : '';

        })

            ->setRowId('id');
    }

    /**
     * Get the query source of dataTable.
     */
    public function query(Purchase $model): QueryBuilder
    {
        //return $model->newQuery()->latest();

        return $model->newQuery()
            ->where(function ($query) {
                $fromDate = $this->request->input('fromdate');
                $toDate = $this->request->input('todate');

                if ($fromDate) {
                    $fromDate = Carbon::parse($fromDate)->startOfDay();
                    $query->where('created_at', '>=', $fromDate);
                }

                if ($toDate) {
                    $toDate = Carbon::parse($toDate)->endOfDay();
                    $query->where('created_at', '<=', $toDate);
                }
            })
            ->latest();



    }

    /**
     * Optional method if you want to use the html builder.
     */
    public function html(): HtmlBuilder
    {
        return $this->builder()
            ->setTableId('orders-table')
            ->columns([
                'vendor' => ['title' => 'Vendor'],

                'customer' => ['title' => 'Customer'],
                'orderdate' => ['title' => 'PO Date'],
                'saleorder_id' => ['title' => 'PO#'],
                'totalAmount' => ['title' => 'Amount'],
           

            ])
            ->minifiedAjax('', null, request()->only(['fromdate', 'todate']))
            //->dom('Bfrtip')
            ->orderBy(1)
            ->selectStyleSingle()
            ->buttons([
                Button::make('excel'),
                Button::make('csv'),
                Button::make('pdf'),
                Button::make('print'),
                Button::make('reset'),
                Button::make('reload')
            ]);
    }

    /**
     * Get the dataTable columns definition.
     */



    public function getColumns(): array
    {
        return [


            'salesRep',
            'status',
            'customer',
            'orderdate',
            'saleorder_id',
            'totalAmount',
            'action',



        ];
    }

    /**
     * Get the filename for export.
     */
    protected function filename(): string
    {
        return 'Orders_' . date('YmdHis');
    }
}
