<?php



namespace App\DataTables\Reports\Sale;



use App\Models\Invoice;

use Illuminate\Database\Eloquent\Builder as QueryBuilder;

use Yajra\DataTables\EloquentDataTable;

use Yajra\DataTables\Html\Builder as HtmlBuilder;

use Yajra\DataTables\Html\Button;

use Yajra\DataTables\Html\Column;

use Yajra\DataTables\Html\Editor\Editor;

use Yajra\DataTables\Html\Editor\Fields;

use Yajra\DataTables\Services\DataTable;

use DateTime;

use Carbon\Carbon;

use App\Facades\Company;



class CoaTaxReport extends DataTable

{



    public $counter = 0;

    public $closingBalance = 0;

    public $openingBalance = 0;

    public $debit = 0;

    public $credit = 0;

    /**

     * Build the DataTable class.

     *

     * @param QueryBuilder $query Results from query() method.

     */

    public function dataTable(QueryBuilder $query): EloquentDataTable

    {



        return (new EloquentDataTable($query))





            ->addColumn('ref', function ($query) {

                $pfc = '';

                if ($query->order_type == 2) {

                    $pfc = 'CN';

                }



                return $query->company ? $pfc . $query->company->companyPrefix . '' . $query->saleorder_id . '-' . $query->invoice_serial : '';

            })

            ->addColumn('invoicedate', function ($query) {

                return date('d M y', strtotime($query->invoicedate));

            })

            ->addColumn('customer', function ($query) {

                $items = '';

                foreach ($query->invoiceItems as $key => $item) {

                    $items .= '(' . ++$key . ') ' . $item->item->description . ' ~ (' . $query->company->companyCurrency . '' . $item->item->price . 'x' . $item->item->quantity . ') ';

                }

                return $query->customer ? $query->customer->company . ', ' . $items : '';

            })

            ->addColumn('creditAmount', function ($query) {



                if ($query->order_type == 1) {

                    $viewTotal = $query->getTotalTaxSumAttribute();

                } else {

                    $viewTotal = 0;

                }

                $this->credit = $viewTotal;

                return $query->company ? $query->company->companyCurrency . '' . number_format($viewTotal, 2) : '';

            })

            ->addColumn('debitAmount', function ($query) {

                if ($query->order_type == 2) {

                    $viewTotal = $query->getTotalTaxSumAttribute();

                } else {

                    $viewTotal = 0;

                }

                $this->debit = $viewTotal;

                return $query->company ? $query->company->companyCurrency . '' . number_format($viewTotal, 2) : '';

            })





            ->addColumn('balance', function ($query) {

                $this->counter++;



                // if ($this->counter == 1) {



                //     $credit = Invoice::where('order_type', 1)

                //         ->where('invoicedate', '<', $this->request->input('fromdate'))

                //         ->get()

                //         ->sum(function ($inv) {

                //             return $inv->invoiceItems->sum(function ($orderItem) {

                //                 return $orderItem->quantity * $orderItem->price;

                //             });

                //         });



                //     $debit = Invoice::where('order_type', 2)

                //         ->where('invoicedate', '<', $this->request->input('fromdate'))

                //         ->get()

                //         ->sum(function ($inv) {

                //             return $inv->invoiceItems->sum(function ($orderItem) {

                //                 return $orderItem->quantity * $orderItem->price;

                //             });

                //         });



                //     $this->openingBalance = $credit - $debit;

                //     $this->closingBalance = $credit - $debit;



                // }


                                if ($this->counter == 1 && $this->request->input('fromdate')) {
                $credit = Invoice::where('order_type', 1)
                    ->where('invoicedate', '<', $this->request->input('fromdate'))
                    ->get()
                    ->sum('totalTaxSum'); 
                $debit = Invoice::where('order_type', 2)
                    ->where('invoicedate', '<', $this->request->input('fromdate'))
                    ->get()
                    ->sum('totalTaxSum'); 
                $this->openingBalance = $credit - $debit;
                $this->closingBalance = $this->openingBalance;
             }



                $this->closingBalance = $this->closingBalance + $this->credit - $this->debit;



                return $query->company ? $query->company->companyCurrency . '' . number_format($this->closingBalance, 2) : '';



            })



            ->addColumn('opening', function ($query) {

                if ($this->counter == 1) {



                    return $query->company ? $query->company->companyCurrency . '' . number_format($this->openingBalance, 2) : '';

                } else {

                    return '';

                }

            })

            ->setRowId('id');



    }



    /**

     * Get the query source of dataTable.

     */

    public function query(Invoice $model): QueryBuilder

    {

        //return $model->newQuery()->latest();



        return $model->newQuery()

            ->whereHas('invoiceTax', function ($query) {

                $query->where('charge_id', '>', 0);

            })

            ->when($state_id = $this->request->input('stateid'), function ($query) use ($state_id) {

                $query->where('shippingState_id', $state_id);

            })

            ->when($fromDate = $this->request->input('fromdate'), function ($query) use ($fromDate) {

                $query->where('invoicedate', '>=', Carbon::parse($fromDate)->startOfDay());

            })

            ->when($toDate = $this->request->input('todate'), function ($query) use ($toDate) {

                $query->where('invoicedate', '<=', Carbon::parse($toDate)->endOfDay());

            })

            ->where('company_id', auth()->user()->company_id)

            ->orderBy('invoicedate', 'asc');







    }



    /**

     * Optional method if you want to use the html builder.

     */

    public function html(): HtmlBuilder

    {

        return $this->builder()

            ->setTableId('orders-table')

            ->columns([



                'ref' => ['title' => 'PO Reference'],

                'opening' => ['title' => 'Opening Balance'],

                'customer' => ['title' => 'Description'],

                'invoicedate' => ['title' => 'Date'],

                'debitAmount' => ['title' => 'Debit'],

                'creditAmount' => ['title' => 'Credit'],

                'balance' => ['title' => 'Balance'],



            ])

            ->minifiedAjax('', null, request()->only(['fromdate', 'todate', 'stateid']))

            //->dom('Bfrtip')

            ->orderBy(1)

            ->selectStyleSingle()

            ->buttons([

                Button::make('excel'),

                Button::make('csv'),

                Button::make('pdf'),

                Button::make('print'),

                Button::make('reset'),

                Button::make('reload')

            ]);

    }



    /**

     * Get the dataTable columns definition.

     */







    public function getColumns(): array

    {

        return [





            'ref',

            'customer',

            'invoicedate',

            'debitAmount',

            'creditAmount',







        ];

    }



    /**

     * Get the filename for export.

     */

    protected function filename(): string

    {

        return 'Orders_' . date('YmdHis');

    }

}

