<?php

namespace App\Http\Controllers\Accounts;



use App\Http\Controllers\Controller;
use App\Models\BankReceipt;
use App\Models\BankReceiptItem;
use App\Models\CashPayment;
use App\Models\CashPaymentItem;
use App\Models\CashReceipt;
use App\Models\CashReceiptItem;
use App\Models\Vendor;
use App\Models\Journal;
use App\Models\JournalItem;
use App\Models\PaymentGateway;
use App\Models\BankPayment;
use App\Models\BankPaymentItem;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Kreait\Firebase\Database\Transaction;

class FinanceController extends Controller
{

    public function bankPayment()
    {
        return view('accounts.finance.bank-payment', [
            'title' => 'Bank Payment', 
            'custom_route' => 'finance.save-bank-payment',
            'amount_type' => 'Debit',
            'transactions' => BankPaymentItem::with('payment')->latest()->paginate(10),
            'vendors' => Vendor::where('company_id', auth()->user()->company_id)->get(),
            'banks' => PaymentGateway::where(['company_id' => auth()->user()->company_id, 'gateway_type' => 'cash', 'isActive' => 1])->get()
        ]);
    }

    public function saveBankPayment(Request $request)
    {
        try {

             DB::beginTransaction();

            // Create a new order

            $transaction = new BankPayment();
            //basic info
            $transaction->company_id = auth()->user()->company_id;
            $transaction->user_id = auth()->user()->id;
            $transaction->recorddate = $request->recorddate;
            $transaction->vendor_id = $request->vendor_id;
            $transaction->gateway_id = $request->bank_id;
            $transaction->save();

            // Create Transaction items
            foreach ($request->description as $key => $itemData) {
                $orderItem = new BankPaymentItem();
                $orderItem->bank_payment_id = $transaction->id;
                $orderItem->description = $itemData;
                $orderItem->amount = $request->amount[$key];
                $orderItem->vdate = $request->vdate[$key];
                
                $orderItem->save();
            }

            DB::commit();

            return redirect()->back()->with('success', 'Transaction Created successfully.');

        } catch (\Exception $e) {
            DB::rollback();
            // Log the error
            Log::error('Transaction failed: ' . $e->getMessage());
            dd($e->getMessage());
            // Handle the exception or error message
        }


    }



    public function bankReceipt()
    {
        // return view('accounts.finance.bank-receipt', [
        //     'vendors' => Vendor::all(),
        //     'banks' => PaymentGateway::all()
        // ]);

        return view('accounts.finance.bank-payment', [
            'title' => 'Bank Receipt', 
            'custom_route' => 'finance.save-bank-receipt',
            'amount_type' => 'Credit',
            'transactions' => BankReceiptItem::with('payment')->latest()->paginate(10),
            'vendors' => Vendor::where('company_id', auth()->user()->company_id)->get(),
            'banks' => PaymentGateway::where(['company_id' => auth()->user()->company_id, 'gateway_type' => 'cash', 'isActive' => 1])->get()
        ]);
    }

   public function saveBankReceipt(Request $request)
    {
        try {

             DB::beginTransaction();

            // Create a new order

            $transaction = new BankReceipt();
            //basic info
            $transaction->company_id = auth()->user()->company_id;
            $transaction->user_id = auth()->user()->id;
            $transaction->recorddate = $request->recorddate;
            $transaction->vendor_id = $request->vendor_id;
            $transaction->gateway_id = $request->bank_id;
            $transaction->save();

            // Create Transaction items
            foreach ($request->description as $key => $itemData) {
                $orderItem = new BankReceiptItem();
                $orderItem->bank_receipt_id = $transaction->id;
                $orderItem->description = $itemData;
                $orderItem->amount = $request->amount[$key];
                $orderItem->vdate = $request->vdate[$key];
                
                $orderItem->save();
            }

            DB::commit();

            return redirect()->back()->with('success', 'Transaction Created successfully.');

        } catch (\Exception $e) {
            DB::rollback();
            // Log the error
            Log::error('Transaction failed: ' . $e->getMessage());
            dd($e->getMessage());
            // Handle the exception or error message
        }


    }




    public function cashPayment()
    {
        // return view('accounts.finance.cash-payment', [
        //     'vendors' => Vendor::where('company_id', auth()->user()->company_id)->get(),
        //     'banks' => PaymentGateway::where(['company_id' => auth()->user()->company_id, 'gateway_type' => 'cash', 'isActive' => 1])->get()
        // ]);

          return view('accounts.finance.bank-payment', [
            'title' => 'Cash Payment', 
            'custom_route' => 'finance.save-cash-payment',
            'amount_type' => 'Debit',
            'transactions' => CashPaymentItem::with('payment')->latest()->paginate(10),
            'vendors' => Vendor::where('company_id', auth()->user()->company_id)->get(),
            'banks' => PaymentGateway::where(['company_id' => auth()->user()->company_id, 'gateway_type' => 'cash', 'isActive' => 1])->get()
        ]);
    }


   public function saveCashPayment(Request $request)
    {
        try {


             DB::beginTransaction();

            // Create a new order

            $transaction = new CashPayment();
            //basic info
            $transaction->company_id = auth()->user()->company_id;
            $transaction->user_id = auth()->user()->id;
            $transaction->recorddate = $request->recorddate;
            $transaction->vendor_id = $request->vendor_id;
            $transaction->gateway_id = $request->bank_id;
            $transaction->save();

            // Create Transaction items
            foreach ($request->description as $key => $itemData) {
                $orderItem = new CashPaymentItem();
                $orderItem->cash_payment_id = $transaction->id;
                $orderItem->description = $itemData;
                $orderItem->amount = $request->amount[$key];
                $orderItem->vdate = $request->vdate[$key];
                
                $orderItem->save();
            }

            DB::commit();

            return redirect()->back()->with('success', 'Transaction Created successfully.');

        } catch (\Exception $e) {
            DB::rollback();
            // Log the error
            Log::error('Transaction failed: ' . $e->getMessage());
            dd($e->getMessage());
            // Handle the exception or error message
        }


    }





    public function cashReceipt()
    {
        // return view('accounts.finance.cash-receipt', [
        //     'vendors' => Vendor::all(),
        //     'banks' => PaymentGateway::all()
        // ]);
         return view('accounts.finance.bank-payment', [
            'title' => 'Cash Receipt', 
            'custom_route' => 'finance.save-cash-receipt',
            'amount_type' => 'Debit',
            'transactions' => CashReceiptItem::with('payment')->latest()->paginate(10),
            'vendors' => Vendor::where('company_id', auth()->user()->company_id)->get(),
            'banks' => PaymentGateway::where(['company_id' => auth()->user()->company_id, 'gateway_type' => 'cash', 'isActive' => 1])->get()
        ]);
    }

   public function saveCashReceipt(Request $request)
    {
        try {


             DB::beginTransaction();

            // Create a new order

            $transaction = new CashReceipt();
            //basic info
            $transaction->company_id = auth()->user()->company_id;
            $transaction->user_id = auth()->user()->id;
            $transaction->recorddate = $request->recorddate;
            $transaction->vendor_id = $request->vendor_id;
            $transaction->gateway_id = $request->bank_id;
            $transaction->save();

            // Create Transaction items
            foreach ($request->description as $key => $itemData) {
                $orderItem = new CashReceiptItem();
                $orderItem->cash_receipt_id = $transaction->id;
                $orderItem->description = $itemData;
                $orderItem->amount = $request->amount[$key];
                $orderItem->vdate = $request->vdate[$key];
                
                $orderItem->save();
            }

            DB::commit();

            return redirect()->back()->with('success', 'Transaction Created successfully.');

        } catch (\Exception $e) {
            DB::rollback();
            // Log the error
            Log::error('Transaction failed: ' . $e->getMessage());
            dd($e->getMessage());
            // Handle the exception or error message
        }


    }


   public function journal()
    {
        // return view('accounts.finance.cash-receipt', [
        //     'vendors' => Vendor::all(),
        //     'banks' => PaymentGateway::all()
        // ]);
         return view('accounts.finance.bank-payment', [
            'title' => 'Journal', 
            'custom_route' => 'finance.save-journal',
            'amount_type' => 'Debit',
            'transactions' => JournalItem::with('payment')->latest()->paginate(10),
            'vendors' => Vendor::where('company_id', auth()->user()->company_id)->get(),
            'banks' => PaymentGateway::where(['company_id' => auth()->user()->company_id, 'gateway_type' => 'cash', 'isActive' => 1])->get()
        ]);
    }

   public function saveJournal(Request $request)
    {
        try {


             DB::beginTransaction();

            // Create a new order

            $transaction = new Journal();
            //basic info
            $transaction->company_id = auth()->user()->company_id;
            $transaction->user_id = auth()->user()->id;
            $transaction->recorddate = $request->recorddate;
            $transaction->vendor_id = $request->vendor_id;
            $transaction->gateway_id = $request->bank_id;
            $transaction->save();

            // Create Transaction items
            foreach ($request->description as $key => $itemData) {
                $orderItem = new JournalItem();
                $orderItem->journal_id = $transaction->id;
                $orderItem->description = $itemData;
                $orderItem->amount = $request->amount[$key];
                $orderItem->vdate = $request->vdate[$key];
                
                $orderItem->save();
            }

            DB::commit();

            return redirect()->back()->with('success', 'Transaction Created successfully.');

        } catch (\Exception $e) {
            DB::rollback();
            // Log the error
            Log::error('Transaction failed: ' . $e->getMessage());
            dd($e->getMessage());
            // Handle the exception or error message
        }


    }

}
