<?php

namespace App\Http\Controllers\Accounts;




use App\Services\InvoiceService;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use Route;


use App\DataTables\Reports\QuotationReport;
use App\DataTables\Reports\PendingQuotationReport;
use App\DataTables\Reports\OrderReport;
use App\DataTables\Reports\PendingOrderReport;
use App\DataTables\Reports\SaleRegister;
use App\DataTables\Reports\InventoryAgingReport;
use App\DataTables\Reports\CreditNoteRegister;
use App\DataTables\Reports\Sale\CoaTaxReport;

use App\DataTables\Reports\Sale\CoaSalesReport;
use App\DataTables\Reports\Sale\CoaFreightReport;
use App\DataTables\Reports\Sale\CoaCreditCardReport;
use App\DataTables\Reports\Sale\CoaGoodSoldReport;

use App\DataTables\Reports\Sale\CoaCustomerReport;
//purchase
use App\DataTables\Reports\Purchase\CoaPurchaseTaxReport;
use App\DataTables\Reports\Purchase\PurchaseRegister;
use App\DataTables\Reports\Purchase\DebitNoteRegister;
use App\DataTables\Reports\Purchase\CoaVendorReport;
use App\DataTables\Reports\Purchase\PurchaseReport;
use App\DataTables\Reports\Purchase\PendingPurchaseReport;
use App\DataTables\Reports\Purchase\CoaPurchaseCarriageInwardReport;
use App\DataTables\Reports\Purchase\CoaPurchaseCreditCardReport;

use App\Facades\Company;

use App\Models\Vendor;


class ReportController extends Controller
{
    protected $datatableFileName = "datatable.report";

    public function quotations(QuotationReport $dataTable)
    {

        $title = 'Quotations Report';
        return $dataTable->render($this->datatableFileName, compact('title'));
    }

    public function pendingQuotations(PendingQuotationReport $dataTable)
    {

        $title = 'Pending Quotations Report';
        return $dataTable->render($this->datatableFileName, compact('title'));
    }


    public function orders(OrderReport $dataTable)
    {

        $title = 'Sale Order Report';
        return $dataTable->render($this->datatableFileName, compact('title'));
    }

    public function pendingorders(PendingOrderReport $dataTable)
    {

        $title = 'Pending Sale Order Report';
        return $dataTable->render($this->datatableFileName, compact('title'));
    }

    public function salesRegister(SaleRegister $dataTable)
    {

        $title = 'Sales Register Report';
        return $dataTable->render($this->datatableFileName, compact('title'));
    }

    public function creditNoteRegister(CreditNoteRegister $dataTable)
    {
        $title = 'Credit Note Reports';
        return $dataTable->render($this->datatableFileName, compact('title'));
    }

    public function inventoryAgingReport(InventoryAgingReport $dataTable)
    {
        $title = '';
        return $dataTable->render($this->datatableFileName, compact('title'));
    }


    public function taxLedger(CoaTaxReport $dataTable)
    {
        $title = 'Tax Acc (State wise)';

        return $dataTable->render($this->datatableFileName, compact('title'));
    }

    public function freightLedger(CoaFreightReport $dataTable)
    {
        $title = 'Freight Acc';
        return $dataTable->render($this->datatableFileName, compact('title'));
    }
    public function ccLedger(CoaCreditCardReport $dataTable)
    {
        $title = 'Credit Card Charges AC';
        return $dataTable->render($this->datatableFileName, compact('title'));
    }

        public function goodSold(CoaGoodSoldReport $dataTable)
    {
        $title = 'Cost of Good Sold';
        return $dataTable->render($this->datatableFileName, compact('title'));
    }


    public function saleLedger(CoaSalesReport $dataTable)
    {

        $title = 'Sales';
        return $dataTable->render($this->datatableFileName, compact('title'));
    }
    public function customerLedger(CoaCustomerReport $dataTable)
    {

        $title = 'Customer Ledger';
        return $dataTable->render($this->datatableFileName, compact('title'));
    }

    public function vendorLedger(CoaVendorReport $dataTable)
    {
          $vendor_id = request()->route('id');
        
          $vendor = Vendor::findOrfail($vendor_id);
           
        $title = 'Vendor ('.$vendor->company.') Ledger';
        return $dataTable->render($this->datatableFileName, compact('title'));
    }

    public function ccPurchase(CoaPurchaseCreditCardReport $dataTable)
    {
        $title = 'Credit Card Charges AC';
        return $dataTable->render($this->datatableFileName, compact('title'));
    }
  public function carriageInward(CoaPurchaseCarriageInwardReport $dataTable)
    {
        $title = 'Carriage Inward';
        return $dataTable->render($this->datatableFileName, compact('title'));
    }


    public function currentPageName()
    {

        $route_name = Route::currentRouteName();

        if ($route_name == 'reports.pending-orders') {
            return 'Pending Sales Order Report';
        }
        if ($route_name == 'reports.orders') {
            return 'Sales Order Report';
        }
        if ($route_name == 'reports.quotations') {
            return 'Quotation Report';
        }
    }


    public function trailBalance()
    {



        $receivables = DB::table('invoices')
            ->leftJoin(DB::raw('(SELECT invoice_id, COALESCE(SUM(quantity * price), 0) AS total_amount_sum FROM invoice_items GROUP BY invoice_id) AS item_totals'), 'invoices.id', '=', 'item_totals.invoice_id')
            ->leftJoin(DB::raw('(SELECT invoice_id, COALESCE(SUM(amount), 0) AS total_charge_sum FROM invoice_charges GROUP BY invoice_id) AS charge_totals'), 'invoices.id', '=', 'charge_totals.invoice_id')
            ->leftJoin(DB::raw('(SELECT invoice_id, COALESCE(SUM(amount), 0) AS total_payment_sum FROM receivable_payments GROUP BY invoice_id) AS payment_totals'), 'invoices.id', '=', 'payment_totals.invoice_id')
            ->where('invoices.company_id', 1)
            ->where('invoices.is_closed', 1)
            ->where('invoices.is_receivable', 0)
            ->groupBy('invoices.company_id')
            ->select(
                'invoices.company_id',
                DB::raw('COALESCE(SUM(item_totals.total_amount_sum), 0) AS total_amount_sum'),
                DB::raw('COALESCE(SUM(charge_totals.total_charge_sum), 0) AS total_charge_sum'),
                DB::raw('COALESCE(SUM(payment_totals.total_payment_sum), 0) AS total_payment_sum')
            )
            ->get();





        return view('accounts.reports.trail-balance', []);



    }




    public function agingSummary()
    {

        $invoices = \App\Models\Invoice::all();
        $company = Company::info();
        return view('sales.reports.aging-summary', ['invoices' => $invoices, 'company' => $company]);

    }
    // public function saleRegister()
    // {

    //     $invoices = $this->invoiceService->allInvoices();
    //     $company = Company::info();
    //     return view('sales.reports.sale-register', ['invoices' => $invoices, 'company' => $company]);

    // }


    //purhcase 

    //purchase part

    public function purchaseRegister(PurchaseRegister $dataTable)
    {

        $title = 'Purchase Register';
        return $dataTable->render($this->datatableFileName, compact('title'));
    }

    public function taxPurchase(CoaPurchaseTaxReport $dataTable)
    {
        $title = 'Tax Acc (State wise)';
        return $dataTable->render($this->datatableFileName, compact('title'));
    }


    public function debitNoteRegister(DebitNoteRegister $dataTable)
    {
        $title = '';
        return $dataTable->render($this->datatableFileName, compact('title'));
    }



    //gross profit 





    protected function processSalesInvoices($order)
    {
        $salesInvoices = [];

        foreach ($order->saleInvoices as $invoice) {
            $salesInvoices[] = [

                'thetype' => '',
                'month' => '',
                'invoice' => $invoice->saleorder_id . '-' . $invoice->invoice_serial,
                'invoice_date' => $invoice->invoicedate,
                'reference' => $invoice->ref,
                'customer' => $invoice->customer->company,
                'state' => $invoice->getStateInfo($invoice->shippingState_id)->name,
                'gross_sale' => (double) $invoice->getTotalAmountSumAttribute(),
                'frieght' => (double) $invoice->getTotalShippingSumAttribute(),
                'tax' => (double) $invoice->getTotalTaxSumAttribute(),
                'invoice_total' => (double) $invoice->getTotalAmountSumAttribute() + $invoice->getTotalChargeSumAttribute(),
                'net_sale_amount' => 0,
            ];
        }

        return $salesInvoices;
    }

    protected function processPurchaseInvoices($order)
    {
        $purchaseInvoices = [];

        foreach ($order->purchaseInvoices as $payable) {
            $purchaseInvoices[] = [
                'po_number' => 0,
                'vendor' => $payable->vendor->company,
                'pinvoice_no' => $payable->saleorder_id,
                'pinvoice_date' => $payable->invoicedate,
                'p_total' => (double) $payable->getTotalAmountSumAttribute(),
                'payable_frieght' => 0,
                'payable_tax' => 0,
                'payable_ecw' => 0,

                'invoice_amount' => 0,

                'payable_tracking' => '',


                'gross_profit' => 0,
            ];
        }

        return $purchaseInvoices;
    }

    protected function fillEmptyRows($emptyRowCount, &$invoices, $type)
    {
        for ($i = 1; $i <= $emptyRowCount; $i++) {
            $emptyRow = [
                'thetype' => ($type === 'sale') ? '-' : '',
                'month' => '-',
                // ... (other columns) ...
            ];
            $invoices[] = $emptyRow;
        }
    }

    protected function combineInvoices($salesInvoices, $purchaseInvoices)
    {
        $combinedInvoices = [];

        foreach ($purchaseInvoices as $key => $purchaseInvoice) {
            $combinedInvoices[] = array_merge($salesInvoices[$key], $purchaseInvoice);
        }

        return $combinedInvoices;
    }


    public function fetchGrossProfit(Request $request)
    {
        if ($request->ajax()) {
            $orders = \App\Models\Order::paginate(10);

            return view('accounts.reports.partials.gp-data', compact('orders'));
        }
    }




    public function purchases(PurchaseReport $dataTable)
    {

        $title = 'Purchase Order Report';
        return $dataTable->render($this->datatableFileName, compact('title'));
    }

    public function pendingpurchases(PendingPurchaseReport $dataTable)
    {

        $title = 'Pending Purchase Order Report';
        return $dataTable->render($this->datatableFileName, compact('title'));
    }



}
