<?php

namespace App\Http\Controllers;
use App\Http\Requests\StoreCustomerRequest;
use App\Http\Requests\UpdateCustomerRequest;

use Illuminate\Http\Request;
use App\Models\Customer;
use App\Services\CountryService;
use App\Services\StateService;
use App\DataTables\CustomerDataTable;

class CustomerController extends Controller
{

    protected $countryService;
    protected $stateService;


    public function __construct(CountryService $countryService, StateService $stateService)
    {
        $this->countryService = $countryService;
        $this->stateService = $stateService;
    }

    // public function index()
    // {
    //     $customers = Customer::latest()->paginate(100); 
    //     return view('customers.index', ['customers' => $customers]);
    // }

    public function index(CustomerDataTable $dataTable)
    {
        
        return $dataTable->render('customers.index');
    }

public function create()
{
    
    return view('customers.create', [
        'customer' => []
    ]);
}


public function store(StoreCustomerRequest $request)
{

   
    $data = $request->validated();
    $data['user_id'] = auth()->user()->id;
    $data['company_id'] = auth()->user()->company_id;
    Customer::create($data);
    return redirect()->route('customers')->with('success', 'Customer created successfully.');

}
public function dataindex()
{
    $customers = Customer::paginate(100); // 10 records per page

    $response = [
        'data' => $customers->items(),
        'total' => $customers->total(),
        'perPage' => $customers->perPage(),
        'currentPage' => $customers->currentPage(),
    ];

    return response()->json($response);
}

public function edit($id)
{
    $customer = Customer::find($id);
    
    return view('customers.edit', [
        'customer' => $customer
    ]);
}

public function update(UpdateCustomerRequest $request, $id)
{

    
    $customer = Customer::findOrFail($id);
    $data = $request->validated();
    
    $customer->update($data);
    return redirect()->route('customers')->with('success', 'Customer updated successfully.');
}


public function userCustomers($id){

    $searchTerm =   request()->input('searchQuery');
    $customers = Customer::select('id', 'company', 'email', 'firstName', 'lastName', 'address', 'city', 'state_id', 'postalCode', 'country_id', 'phone')
    //->where('user_id', $id)
    ->where('company', 'LIKE', '%' . $searchTerm . '%')
    ->where('company_id', \Auth::user()->company_id)
    ->limit(5)
    ->get(); 

    return response()->json($customers);
}


}
