<?php

namespace App\Http\Controllers\FixedAssets;

use App\Services\OrderService;
use App\Services\PurchaseService;
use App\Http\Requests\StorePurchaseRequest;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Facades\Company;
use App\Models\FixedAsset;
use App\Models\FixedAssetItem;
use App\Models\FixedAssetCharge;
use App\Models\PurchaseReceiving;
use App\DataTables\PurchaseDataTable;
use App\DataTables\FixedAssets\FixedAssetDataTable;

use Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;

class FixedAssetImpairmentController extends Controller
{

    use \App\Http\Controllers\Traits\Functions;




    public function index(FixedAssetDataTable $dataTable)
    {

        $title = 'Fixed Assets Impairment';
        return $dataTable->render('datatable.report', compact('title'));

    }



    public function create()
    {

        $title = 'Fixed Assets';

        $company = Company::info();

        // $sources = $this->alloptions('source');
        $payments = $this->alloptions('payment');
        // $shippings = $this->alloptions('shipping');
        // $charges = $this->alloptions('charges');
        // $taxes = $this->alloptions('tax');
        // $countries = \App\Models\Country::all();



        return view('fixed-assets.orders.create', [
            'customer' => [],
            'order' => [],
            // 'sources' => $sources,
            'payments' => $payments,
            // 'charges' => $charges,
            // 'shippings' => $shippings,
            // 'taxes' => $taxes,
            // 'brands' => $brands,
            // 'quoteid' => 'NA'
        ]);


    }

    public function store(Request $request)
    {


        try {

            DB::beginTransaction();

            // Create a new order


            $order = new FixedAsset();

            //basic info
            $order->company_id = auth()->user()->company_id;
            $order->purchasedate = $request->purchasedate;
            $order->ref = $request->ref;
            $order->vendor_id = $request->vendor_id;
            //billing info
            $order->billingPerson = $request->billingPerson;
            $order->billingPhone = $request->billingPhone;
            $order->billingEmail = $request->billingEmail;
            $order->billingCountry_id = $request->billingCountry_id;
            $order->billingState_id = $request->billingState_id;
            $order->billingCity = $request->billingCity;
            $order->billingPostal = $request->billingPostal;
            $order->billingAddress = $request->billingAddress;

            //shiping info
            $order->shippingContact = $request->shippingContact;
            $order->shippingCompany = $request->shippingCompany;
            $order->shippingPhone = $request->shippingPhone;
            $order->shippingEmail = $request->shippingEmail;
            $order->shippingCountry_id = $request->shippingCountry_id;
            $order->shippingState_id = $request->shippingState_id;
            $order->shippingCity = $request->shippingCity;
            $order->shippingPostal = $request->shippingPostal;
            $order->shippingAddress = $request->shippingAddress;
            $order->user_id = auth()->user()->id;

            $order->save();

            // Create order items
            foreach ($request->item as $key => $itemData) {

                $orderItem = new FixedAssetItem();
                $orderItem->fixed_asset_id = $order->id;
                $orderItem->item_name = $itemData;
                $orderItem->quantity = $request->quantity[$key];
                $orderItem->price = $request->price[$key];
                $orderItem->save();
            }

            // Create order charges
            // foreach ($request->charge_id as $key => $chargeData) {
            //     if ($request->charge[$key] != 0) {
            //         $orderCharge = new PurchaseCharge();
            //         $orderCharge->purchase_id = $order->id;
            //         $orderCharge->charge_id = $chargeData;
            //         $orderCharge->amount = $request->charge[$key];
            //         $orderCharge->save();

            //     }

            // }

            DB::commit();

            return redirect()->route('fixed-assets')->with('success', 'Purchase Created successfully.');

        } catch (\Exception $e) {
            DB::rollback();
            // Log the error
            Log::error('Purchase Transaction failed: ' . $e->getMessage());
            dd($e->getMessage());
            // Handle the exception or error message
        }



    }

    public function show($id)
    {

        $purchase = FixedAsset::where('id', $id)->first();

        $company = Company::info();
        return view('fixed-assets.view', ['purchase' => $purchase, 'company' => $company]);
    }

    public function receivings($id)
    {
        $purchase = $this->purchaseService->findPurchase($id);
        $receivings = $this->purchaseService->findPurchaseReceivings($id);

        $company = Company::info();
        return view('purchase.receivings', ['purchase' => $purchase, 'receivings' => $receivings, 'company' => $company]);
    }


    public function receivingStore(Request $request, $id)
    {
        $request->validate([
            'invoiceNumber' => 'required',
            'invoiceDate' => 'required',
            'quantity' => 'required',
            'vendor_id' => 'required',
            'trackingNumber' => 'required',
            'productCost' => 'required',
            'freight' => 'required',
            'tax' => 'required',
            'ecw' => 'required'
        ]);

        $receiving = new PurchaseReceiving();
        $receiving->invoiceNumber = $request->invoiceNumber;
        $receiving->vendor_id = $request->vendor_id;
        $receiving->invoiceDate = $request->invoiceDate;
        $receiving->quantity = $request->quantity;
        $receiving->trackingNumber = $request->trackingNumber;
        $receiving->productCost = $request->productCost;
        $receiving->freight = $request->freight;
        $receiving->tax = $request->tax;
        $receiving->ecw = $request->ecw;
        $receiving->company_id = auth()->user()->company_id;
        $receiving->purchase_id = $id;
        $receiving->user_id = auth()->user()->id;
        $receiving->save();


        return redirect()->back()->with('success', 'Receiving created successfully.');
    }


}
