<?php

namespace App\Http\Controllers\Purchase;

use App\Models\Alloption;
use App\Services\OrderService;
use App\Services\PurchaseService;
use App\Http\Requests\StorePurchaseRequest;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Facades\Company;
use App\Models\Purchase;
use App\Models\PurchaseItem;
use App\Models\PurchaseCharge;
use App\Models\PurchaseReceiving;
use App\DataTables\PurchaseDataTable;
use App\DataTables\Purchase\PurchaseableDataTable;

use Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;

class PurchaseController extends Controller
{

    use \App\Http\Controllers\Traits\Functions;


    protected $orderService;
    protected $purchaseService;

    public function __construct(OrderService $orderService, PurchaseService $purchaseService)
    {
        $this->orderService = $orderService;
        $this->purchaseService = $purchaseService;
    }

    public function index(PurchaseDataTable $dataTable)
    {


        $title = 'Purchases';
        return $dataTable->render('datatable.report', compact('title'));

    }

    public function purchaseable(PurchaseableDataTable $dataTable)
    {


        $title = 'Purchases';
        return $dataTable->render('datatable.report', compact('title'));

    }


    public function saleorder($id)
    {

        $order = $this->orderService->findOrder($id);

        $purchases = Purchase::where('order_id', $id)->get();

        $company = Company::info();

        $customer = [];
        $payments = $this->alloptions('payment');
        return view('purchase.orders.sale', ['order' => $order, 'company' => $company, 'customer' => $customer, 'purchases' => $purchases, 'payments' => $payments]);
    }

    public function store(StorePurchaseRequest $request, $id)
    {

        $request->validate([
            'customer_id' => 'required',
            'saleorder_id' => 'required',
            'vendor_id' => 'required',
            'purchasedate' => 'required',
            'ref' => 'required',
            'payment_id' => 'required'

        ]);

        try {

            DB::beginTransaction();

            // Create a new order
            $groupId = 1;
            $existing = Purchase::where('order_id', $id)->exists();
            if ($existing) {
                $purchaseGroup = Purchase::select('purchaseGroup')->where('order_id', $id)->latest()->first();
                $groupId = $purchaseGroup->purchaseGroup + 1;
            }


            $order = new Purchase();

            //basic info
            $order->company_id = auth()->user()->company_id;
            $order->customer_id = $request->customer_id;
            $order->saleorder_id = $request->saleorder_id;
            $order->ref = $request->ref;
            $order->vendor_id = $request->vendor_id;
            $order->purchasedate = $request->purchasedate;
            $order->payment_id = $request->payment_id;
            $order->order_id = $id;
            $order->purchaseGroup = $groupId;

            //billing info
            $order->billingPerson = $request->billingPerson;
            $order->billingPhone = $request->billingPhone;
            $order->billingEmail = $request->billingEmail;
            $order->billingCountry_id = $request->billingCountry_id;
            $order->billingState_id = $request->billingState_id;
            $order->billingCity = $request->billingCity;
            $order->billingPostal = $request->billingPostal;
            $order->billingAddress = $request->billingAddress;

            //shiping info
            $order->shippingContact = $request->shippingContact;
            $order->shippingCompany = $request->shippingCompany;
            $order->shippingPhone = $request->shippingPhone;
            $order->shippingEmail = $request->shippingEmail;
            $order->shippingCountry_id = $request->shippingCountry_id;
            $order->shippingState_id = $request->shippingState_id;
            $order->shippingCity = $request->shippingCity;
            $order->shippingPostal = $request->shippingPostal;
            $order->shippingAddress = $request->shippingAddress;
            $order->user_id = auth()->user()->id;

            $order->save();

            // Create order items
            foreach ($request->item_id as $key => $itemData) {

                $orderItem = new PurchaseItem();
                $orderItem->purchase_id = $order->id;
                $orderItem->item_id = $itemData;
                $orderItem->quantity = $request->quantity[$key];
                $orderItem->price = $request->price[$key];
                $orderItem->save();
            }

            // Create order charges
            foreach ($request->charge_id as $key => $chargeData) {
                if ($request->charge[$key] != 0) {
                    $orderCharge = new PurchaseCharge();
                    $orderCharge->purchase_id = $order->id;
                    $orderCharge->charge_id = $chargeData;
                    $orderCharge->amount = $request->charge[$key];
                    $orderCharge->save();

                }

            }

            DB::commit();

            return redirect()->back()->with('success', 'Purchase Created successfully.');

        } catch (\Exception $e) {
            DB::rollback();
            // Log the error
            Log::error('Purchase Transaction failed: ' . $e->getMessage());
            dd($e->getMessage());
            // Handle the exception or error message
        }



    }

    public function show($id)
    {

        $purchase = $this->purchaseService->findPurchase($id);
        $company = Company::info();
        return view('purchase.view', ['purchase' => $purchase, 'company' => $company]);
    }

    public function receivings($id)
    {
        $purchase = $this->purchaseService->findPurchase($id);
        $receivings = $this->purchaseService->findPurchaseReceivings($id);

        $company = Company::info();
        return view('purchase.receivings', ['purchase' => $purchase, 'receivings' => $receivings, 'company' => $company]);
    }


    public function receivingStore(Request $request, $id)
    {
        $request->validate([
            'invoiceNumber' => 'required',
            'invoiceDate' => 'required',
            'quantity' => 'required',
            'vendor_id' => 'required',
            'trackingNumber' => 'required',
            'productCost' => 'required',
            'freight' => 'required',
            'tax' => 'required',
            'ecw' => 'required'
        ]);

        $receiving = new PurchaseReceiving();
        $receiving->invoiceNumber = $request->invoiceNumber;
        $receiving->vendor_id = $request->vendor_id;
        $receiving->invoiceDate = $request->invoiceDate;
        $receiving->quantity = $request->quantity;
        $receiving->trackingNumber = $request->trackingNumber;
        $receiving->productCost = $request->productCost;
        $receiving->freight = $request->freight;
        $receiving->tax = $request->tax;
        $receiving->ecw = $request->ecw;
        $receiving->company_id = auth()->user()->company_id;
        $receiving->purchase_id = $id;
        $receiving->user_id = auth()->user()->id;
        $receiving->save();


        return redirect()->back()->with('success', 'Receiving created successfully.');
    }



    public function edit($id)
    {

        $purchase = $this->purchaseService->findPurchase($id);
        $company = Company::info();


        $sources = $this->alloptions('source');
        $payments = $this->alloptions('payment');
        $shippings = $this->alloptions('shipping');
        $charges = $this->alloptions('charges');
        $taxes = $this->alloptions('tax');
        $countries = \App\Models\Country::all();
        $company = Company::info();
        $acharges = Alloption::where(['optionModule' => 'purchase', 'optionStatus' => 1, 'company_id' => auth()->user()->company_id])
            ->whereIn('optionType', ['shipping', 'tax', 'charges'])->orderBy('orderBy', 'asc')->get();
        return view('purchase.orders.edit', [
            'purchase' => $purchase,
            'sources' => $sources,
            'payments' => $payments,
            'acharges' => $acharges,
            'company' => $company,
            // 'shippings'  => $shippings,
            // 'taxes' => $taxes
        ]);

    }

}
