<?php



namespace App\Http\Controllers\Purchase;



use App\Http\Controllers\Controller;



use App\Models\PurchaseInvoice;

use App\Models\PurchaseInvoiceItem;

use App\Models\PurchaseInvoiceCharge;
use App\Models\Alloption;


use App\Services\PurchaseService;

use App\Services\PurchaseInvoiceService;



use Illuminate\Support\Facades\DB;

use Illuminate\Support\Facades\Log;



use Illuminate\Http\Request;

use App\Http\Requests\StoreQuoteRequest;



use App\Models\Invoice;

use App\Facades\Company;

//InvoiceDataTable





use App\Models\PaymentGateway;





use App\DataTables\PurchaseDataTable;

use App\DataTables\Purchase\PurchaseInvoiceTable;

use App\DataTables\Purchase\DebitNoteDataTable;





class PurchaseInvoiceController extends Controller

{



    use \App\Http\Controllers\Traits\Functions;







    protected $purchaseService;

    protected $purchaseInvoiceService;

    public function __construct(PurchaseService $purchaseService, PurchaseInvoiceService $purchaseInvoiceService)

    {



        $this->purchaseService = $purchaseService;

        $this->purchaseInvoiceService = $purchaseInvoiceService;

    }





    public function index(PurchaseInvoiceTable $dataTable)

    {



        $title = 'Purchase Invoices';

        return $dataTable->render('datatable.report', compact('title'));

    }



    public function debitnotes(DebitNoteDataTable $dataTable)

    {

        $title = 'Purchase Debit Notes';

        return $dataTable->render('datatable.report', compact('title'));

    }



    private function allRequestInputs()

    {

        $whereConditionArray = [];

        $parameters = request()->input();



        if ($parameters['type-data'] == 'quotes') {

            $whereConditionArray['orderType'] = 0;

        } else {

            $whereConditionArray['orderType'] = 1;

        }



        return $whereConditionArray;

    }







    public function store(Request $request, $id)

    {





        try {



            DB::beginTransaction();



            // Create a new order

            $exorder = $this->purchaseService->findPurchase($id);



            $order_type = $request->order_type ? $request->order_type : 1;

            $name_type = $request->order_type ? 'Debit Note' : 'Invoice';

            $count_inv = PurchaseInvoice::where(['purchase_id' => $exorder->id, 'order_type' => $order_type])->count();

            $inv_serial = $count_inv + 1;

            $debit_note_invoice_id = $request->debit_note_invoice_id ? $request->debit_note_invoice_id : null;



            $order = new PurchaseInvoice();



            //basic info

            $order->company_id = auth()->user()->company_id;

            $order->purchase_id = $id;

            $order->order_id = $request->order_id;
            $order->payment_gateway_id = $request->payment_gateway_id;
            $order->user_id = auth()->user()->id;

            $order->invoicedate = $request->invdate;

            $order->duedate = $request->duedate;

            $order->ref = $request->ref;

            $order->vendor_id = $exorder->vendor_id;

            $order->purchaseGroup = $exorder->purchaseGroup;

            $order->order_type = $order_type;

            $order->debit_note_invoice_id = $debit_note_invoice_id;

            //billing info



            $order->billingPerson = $request->billingPerson;

            $order->billingPhone = $request->billingPhone;

            $order->billingEmail = $request->billingEmail;

            $order->billingCountry_id = $request->billingCountry_id;

            $order->billingState_id = $request->billingState_id;

            $order->billingCity = $request->billingCity;

            $order->billingPostal = $request->billingPostal;

            $order->billingAddress = $request->billingAddress;



            //shiping info

            $order->shippingContact = $request->shippingContact;

            $order->shippingCompany = $request->shippingCompany;

            $order->shippingPhone = $request->shippingPhone;

            $order->shippingEmail = $request->shippingEmail;

            $order->shippingCountry_id = $request->shippingCountry_id;

            $order->shippingState_id = $request->shippingState_id;

            $order->shippingCity = $request->shippingCity;

            $order->shippingPostal = $request->shippingPostal;

            $order->shippingAddress = $request->shippingAddress;

            $order->saleorder_id = $exorder->saleorder_id;

            $order->invoice_serial = $inv_serial;



            $order->save();



            // Create order items

            foreach ($request->item as $key => $itemData) {



                $orderItem = new PurchaseInvoiceItem();

                $orderItem->purchase_invoice_id = $order->id;

                //$orderItem->brand_id = $order->brand_id;

                $orderItem->item_id = $itemData;

                $orderItem->quantity = $request->quantity[$key];

                $orderItem->price = $request->price[$key];

                $orderItem->save();

            }

            //dd($request->charge);

            // Create order charges

            foreach ($request->charge_id as $key => $chargeData) {



                if ($request->charge[$key] > 0) {

                    $orderCharge = new PurchaseInvoiceCharge();

                    $orderCharge->purchase_invoice_id = $order->id;

                    $orderCharge->charge_id = $chargeData;

                    $orderCharge->amount = $request->charge[$key];

                    $orderCharge->save();

                }

            }









            DB::commit();



            return redirect()->back()->with('success', $name_type . ' Created successfully.');



        } catch (\Exception $e) {

            DB::rollback(); // Something went wrong, rollback the changes



            // Log the error

            Log::error('Transaction failed: ' . $e->getMessage());

            dd($e->getMessage());

            // Handle the exception or error message

        }







    }





    public function show($id)

    {



        $order = $this->purchaseInvoiceService->findOrder($id);

        $company = Company::info();

        return view('purchase.invoices.view', ['order' => $order, 'company' => $company]);

    }



    public function debitnotes_show($id)

    {



        $order = $this->purchaseInvoiceService->findOrder($id);

        $company = Company::info();

        return view('purchase.debitnotes.view', ['order' => $order, 'company' => $company]);

    }





    public function orderInvoices()

    {



        $invoices = $this->purchaseInvoiceService->allPurchaseInvoices();

        $id = request()->get('ref_public_key');



        $order = $this->purchaseService->findPurchase($id);



        $company = Company::info();

        $payments = PaymentGateway::where('company_id', $company->id)->where('isActive', 1)->get();





        return view('purchase.invoices.order-invoices', ['invoices' => $invoices, 'company' => $company, 'order' => $order, 'payments' => $payments]);



    }



    public function payableInvoices($id)

    {

       



        // $invoices->each(function ($invoice) {

        //     $invoice->total_amount_sum = $invoice->total_amount_sum;

        //     $invoice->total_payment_sum = $invoice->total_payment_sum;

        //     $invoice->total_charge_sum = $invoice->total_charge_sum;

        // });



        // return response()->json($invoices);


            $invoices = PurchaseInvoice::where(['is_payable' => 1, 'company_id' => auth()->user()->company_id, 'vendor_id' => $id])->whereNull('debit_note_invoice_id')->get();

        $invoices->each(function ($invoice) {
            $memos = PurchaseInvoice::where(['debit_note_invoice_id' => $invoice->id, 'company_id' => auth()->user()->company_id])->get();

            $memo_total_amount_sum = 0;

            $memo_total_charge_sum = 0;

            foreach ($memos as $memo) {
                $memo_total_amount_sum += $memo->total_amount_sum;
                $memo_total_charge_sum += $memo->total_charge_sum;
            }

            // $invoice->total_amount_sum -= $memo_total_amount_sum;
            // $invoice->total_payment_sum -= $memo_total_payment_sum;
            // $invoice->total_charge_sum -= $memo_total_charge_sum;
            $invoice->total_amount_sum = $invoice->total_amount_sum;
            $invoice->total_payment_sum = $invoice->total_amount_sum;
            $invoice->total_charge_sum = $invoice->total_amount_sum;
            $invoice->memo_amount_sum = $memo_total_amount_sum + $memo_total_charge_sum;
        });

        // Return the receivable invoices as a JSON response
        return response()->json($invoices);

    }





    public function invoiceDebitNotes()

    {





        $saleorder_id = request()->get('ref_public_key');

        $id = request()->get('ref_public_parent');



        $order = $this->purchaseInvoiceService->findOrder($id);



        $invoices = $this->purchaseInvoiceService->allPurchaseInvoices();

        $company = Company::info();

        $payments = PaymentGateway::where('company_id', $company->id)->where('isActive', 1)->get();

 $acharges = Alloption::where(['optionModule' => 'purchase', 'optionStatus' => 1, 'company_id' => auth()->user()->company_id])
            ->whereIn('optionType', ['shipping', 'tax', 'charges', 'cc', 'ci'])->orderBy('orderBy', 'asc')->get();

        return view('purchase.debitnotes.order-debitnotes', ['invoices' => $invoices, 'company' => $company, 'order' => $order, 'payments' => $payments ,'acharges' => $acharges]);



    }







}

