<?php



namespace App\Http\Controllers;



use App\Models\COA\SubAccount;

use App\Services\OrderService;

use App\Facades\Company;

use Illuminate\Support\Facades\DB;

use Illuminate\Support\Facades\Log;

use App\Http\Controllers\Controller;

use Illuminate\Http\Request;

use App\Http\Requests\StoreQuoteRequest;



use App\Models\Quotation;

use App\Models\Order;



use App\Models\Alloption;



use App\Models\OrderItem;

use App\Models\OrderCharge;

use App\Models\QuotationItem;

use App\Models\QuotationCharge;

use App\Models\Customer;





use App\Models\Attachment;



use App\DataTables\QuotesDataTable;





class QuotationController extends Controller

{



    use \App\Http\Controllers\Traits\Functions;







    public function index(QuotesDataTable $dataTable)

    {



        return $dataTable->render('sales.quotes.index');

    }



    private function allRequestInputs()

    {

        $whereConditionArray = [];

        $parameters = request()->input();



        if ($parameters['type-data'] == 'quotes') {

            $whereConditionArray['orderType'] = 0;

        } else {

            $whereConditionArray['orderType'] = 1;

        }



        return $whereConditionArray;

    }



    public function create()

    {



        $sources = $this->alloptions('source');

        $payments = $this->alloptions('payment');

        $shippings = $this->alloptions('shipping');

        $charges = $this->alloptions('charges');

        $taxes = $this->alloptions('tax');

        $countries = \App\Models\Country::all();



        $brands = \App\Models\Brand::where('status', 1)->orderBy('order_by', 'ASC')->get();





        return view('sales.orders.create', [

            'customer' => [],

            'order' => [],

            'sources' => $sources,

            'payments' => $payments,

            'charges' => $charges,

            'shippings' => $shippings,

            'taxes' => $taxes,

            'brands' => $brands,

            'quoteid' => 'NA'

        ]);

    }





    public function store(StoreQuoteRequest $request)

    {



        $allOptioncharges = Alloption::select('id', 'multiplyAmount')->where(['optionModule' => 'sale', 'optionStatus' => 1, 'company_id' => auth()->user()->company_id])->get();



        $allcharges = [];



        foreach ($allOptioncharges as $charge) {

            $allcharges[$charge->id] = $charge->multiplyAmount;

        }



        try {



            DB::beginTransaction();



            // Create a new order



            $customer_id = $request->customer_id;

            if (!$customer_id) {

                $customer = Customer::where('company', $request->billingCompany)->first();

                if ($customer) {

                    $customer_id = $customer->id;

                } else {



                    $customer = new Customer();

                    $customer->email = $request->billingEmail;

                    $customer->firstName = $request->billingPerson;

                    $customer->lastName = '';

                    $customer->company = $request->billingCompany;

                    $customer->phone = $request->billingPhone;

                    $customer->country_id = $request->billingCountry_id;

                    $customer->state_id = $request->billingState_id;

                    $customer->city = $request->billingCity;

                    $customer->address = $request->billingAddress;

                    $customer->postalCode = $request->billingPostal;

                    $customer->company_id = auth()->user()->company_id;

                    $customer->user_id = auth()->user()->id;

                    $customer->save();

                    $customer_id = $customer->id;

                }

            }











            $order = new Quotation();



            //basic info

            $order->company_id = auth()->user()->company_id;

            $order->customer_id = $customer_id;

            $order->ref = $request->ref;

            $order->department_id = $request->department_id;

            $order->quoteid = $request->quoteid;

            $order->quotedate = $request->quotedate;

            $order->payment_id = $request->payment_id;



            //billing info



            $order->billingPerson = $request->billingPerson;

            $order->billingPhone = $request->billingPhone;

            $order->billingEmail = $request->billingEmail;

            $order->billingCountry_id = $request->billingCountry_id;

            $order->billingState_id = $request->billingState_id;

           // $order->billingCounty_id = 1;

            $order->billingCity = $request->billingCity;

            $order->billingPostal = $request->billingPostal;

            $order->billingAddress = $request->billingAddress;



            //shiping info

            $order->shippingContact = $request->shippingContact;

            $order->shippingCompany = $request->shippingCompany;

            $order->shippingPhone = $request->shippingPhone;

            $order->shippingEmail = $request->shippingEmail;

            $order->shippingCountry_id = $request->shippingCountry_id;

            $order->shippingState_id = $request->shippingState_id;

            //$order->shippingCounty_id = 1;

            $order->shippingCity = $request->shippingCity;

            $order->shippingPostal = $request->shippingPostal;

            $order->shippingAddress = $request->shippingAddress;

            $order->user_id = $request->user_id;

            $order->createdUserId = auth()->user()->id;



            $order->save();



            // Create order items

            foreach ($request->item as $key => $itemData) {



                $orderItem = new QuotationItem();

                $orderItem->quotation_id = $order->id;

                $orderItem->name = $itemData;

                $orderItem->description = $request->description[$key];

                $orderItem->brand_id = $request->brand_id[$key];

                $orderItem->quantity = $request->quantity[$key];

                $orderItem->price = $request->price[$key];

                $orderItem->save();

            }



            // Create order charges





            foreach ($request->charge_id as $key => $chargeData) {

                if ($request->charge[$key] > 0) {



                    $orderCharge = new QuotationCharge();

                    $orderCharge->quotation_id = $order->id;

                    $orderCharge->charge_id = $chargeData;

                    $orderCharge->amount = $request->charge[$key] * $allcharges[$orderCharge->charge_id];

                    $orderCharge->percentage = $request->charge_percentage[$key];

                    $orderCharge->save();



                }



            }



            DB::commit(); // Everything went well, commit the changes





            return redirect()->route('quotes.show', ['id' => $order->id])->with('success', 'Quote created successfully.');



        } catch (\Exception $e) {

            DB::rollback(); // Something went wrong, rollback the changes



            // Log the error

            Log::error('Transaction failed: ' . $e->getMessage());

            dd($e->getMessage());

            // Handle the exception or error message

        }







    }



    public function edit($id)

    {

        $order = Quotation::findOrFail($id);

        $sources = $this->alloptions('source');

        $payments = $this->alloptions('payment');

        // $shippings = $this->alloptions('shipping');

        // $charges = $this->alloptions('charges');

        // $taxes = $this->alloptions('tax');

        $countries = \App\Models\Country::all();

        $brands = \App\Models\Brand::where('status', 1)->orderBy('order_by', 'ASC')->get();



        $acharges = Alloption::where(['optionModule' => 'sale', 'optionStatus' => 1, 'company_id' => auth()->user()->company_id])

            ->whereIn('optionType', ['shipping', 'tax', 'charges'])->orderBy('orderBy', 'asc')->get();

        return view('sales.quotes.edit', [



            'order' => $order,

            'brands' => $brands,

            'sources' => $sources,

            'payments' => $payments,

            //'charges'  => $charges,

            'acharges' => $acharges,

            //'shippings'  => $shippings,

            //'taxes' => $taxes



        ]);



    }



    public function update(UpdateCustomerRequest $request, $id)

    {

        $customer = Customer::findOrFail($id);

        $data = $request->validated();



        $customer->update($data);

        return redirect()->route('customers')->with('success', 'Customer updated successfully.');

    }



    public function show($id)

    {



        $order = Quotation::findOrFail($id);

        $company = Company::info();

        return view('sales.quotes.view', ['order' => $order, 'company' => $company]);

    }





    public function convertOrder($id)

    {



        $order = Quotation::findOrFail($id);

        return view('sales.quotes.convert-form', ['order' => $order]);

    }











    public function storeConvertOrder(Request $request, $id)

    {





        try {



            DB::beginTransaction();





            $quotation = Quotation::findOrFail($id);



            //dd($quotation->cus);

            if ($quotation->orderType == 1) {

                echo '<h1 style="text-align:center">Already Converted to Sale Order</h1>';

                die;

            } else {



                $quotation->orderType = 1;

                $quotation->status_id = 1;

                $quotation->save();

            }



            $order = new Order();



            //basic info

            $order->company_id = auth()->user()->company_id;

            $order->customer_id = $quotation->customer_id;

            $order->ref = $quotation->ref;

            $order->department_id = $quotation->department_id;

            $order->orderdate = $request->orderdate;



            $order->payment_id = $quotation->payment_id;

            $order->orderType = 1;

            $order->status_id = 1;





            //billing info



            $order->billingPerson = $quotation->billingPerson;

            $order->billingPhone = $quotation->billingPhone;

            $order->billingEmail = $quotation->billingEmail;

            $order->billingCountry_id = $quotation->billingCountry_id;

            $order->billingState_id = $quotation->billingState_id;

            $order->billingCity = $quotation->billingCity;

            $order->billingPostal = $quotation->billingPostal;

            $order->billingAddress = $quotation->billingAddress;



            //shiping info

            $order->shippingContact = $quotation->shippingContact;

            $order->shippingCompany = $quotation->shippingCompany;

            $order->shippingPhone = $quotation->shippingPhone;

            $order->shippingEmail = $quotation->shippingEmail;

            $order->shippingCountry_id = $quotation->shippingCountry_id;

            $order->shippingState_id = $quotation->shippingState_id;

            $order->shippingCity = $quotation->shippingCity;

            $order->shippingPostal = $quotation->shippingPostal;

            $order->shippingAddress = $quotation->shippingAddress;

            $order->user_id = $quotation->user_id;

            $order->createdUserId = auth()->user()->id;

            $order->save();



            // Create order items

            foreach ($quotation->quotationItems as $key => $item) {



                $orderItem = new OrderItem();

                $orderItem->order_id = $order->id;

                $orderItem->name = $item->name;

                $orderItem->description = $item->description;

                $orderItem->quantity = $item->quantity;

                $orderItem->price = $item->price;

                $orderItem->save();



            }



            // Create order charges

            foreach ($quotation->quotationCharges as $key => $charge) {



                $orderCharge = new OrderCharge();

                $orderCharge->order_id = $order->id;

                $orderCharge->charge_id = $charge->charge_id;

                $orderCharge->amount = $charge->amount;

                $orderCharge->save();





            }







            $oid = $order->id;

            $shipping = new \App\Models\OrderShipping();

            $shipping->order_id = $oid;

            $shipping->shipping_id = 1;

            $shipping->message = $request->message;

            $shipping->account_no = $request->account_no;

            $shipping->user_id = auth()->user()->id;

            $shipping->save();



            // update order

            $oid = $order->id;

            $rorder = Order::findOrFail($oid);

            $rorder->saleorder_id = $shipping->id;

            $rorder->save();



            $orderpayment = Alloption::where('id', $quotation->payment_id)->pluck('multiplyAmount');



            // dd([

            //     'name' => $quotation->customer->company,

            //     'related_type' => 'App\Models\Customer',

            //     'code' => $this->sub_account_code(7),

            //     'related_id' => $quotation->customer->id,

            //     'company_id' => auth()->user()->company_id,

            //     'coa_account_head_id' => 7

            // ]);



            if ($orderpayment[0] < 1) {



                $subaccountExist = SubAccount::where('related_type', 'App\Models\Customer')->where('related_id', $quotation->customer->id)->exists();



                if (!$subaccountExist) {



                    $subaccount = new SubAccount();

                    $subaccount->name = $quotation->customer->company;

                    $subaccount->related_type = 'App\Models\Customer';

                    $subaccount->code = $this->sub_account_code(7);

                    $subaccount->related_id = $quotation->customer->id;

                    $subaccount->company_id = auth()->user()->company_id;

                    $subaccount->coa_account_head_id = 7;

                    $subaccount->reportLink = '/coa/customer/' . $quotation->customer->id;



                    $subaccount->save();



                }



            }



            DB::commit(); // Everything went well, commit the changes



            //return redirect()->route('orders')->with('success', 'Order Created successfully.');

            return redirect()->route('orders.show', ['id' => $order->id])->with('success', 'Order created successfully.');





        } catch (\Exception $e) {

            DB::rollback(); // Something went wrong, rollback the changes



            // Log the error

            Log::error('Transaction failed: ' . $e->getMessage());

            dd($e->getMessage());

            // Handle the exception or error message

        }





    }











    public function basic(Request $request, $id)

    {





        $data = $request->except('_token');

        DB::table('quotations')->where('id', $id)->update($data);

        return redirect()->back()->with('success', 'Quotation updated successfully.');



    }



    public function address(Request $request, $id)

    {



        $data = $request->except(['_token' , 'billingCompany']);

        DB::table('quotations')->where('id', $id)->update($data);

        return redirect()->back()->with('success', 'Quotation updated successfully.');

    }

    public function items(Request $request, $id)

    {



        try {



            DB::beginTransaction();







            // Fetch the existing records from the database

            $existingRecords = DB::table('quotation_items')->where('quotation_id', $id)->get();



            // Create an array to keep track of processed 'name' values

            $processedNames = [];



            foreach ($request->input('item') as $index => $name) {

                $description = $request->input('description')[$index];

                $quantity = $request->input('quantity')[$index];

                $price = $request->input('price')[$index];



                // Find the existing record with the same 'name' value, if it exists

                $existingRecord = $existingRecords->firstWhere('name', $name);



                if ($existingRecord) {

                    // Update the existing record

                    DB::table('quotation_items')

                        ->where('id', $existingRecord->id)

                        ->update([

                            'description' => $description,

                            'quantity' => $quantity,

                            'price' => $price,

                        ]);



                    // Mark this 'name' value as processed

                    $processedNames[] = $name;

                } else {

                    // Insert a new record for the 'name' value if it's not processed

                    if (!in_array($name, $processedNames)) {

                        DB::table('quotation_items')->insert([

                            'quotation_id' => $id,

                            'name' => $name,

                            'description' => $description,

                            'quantity' => $quantity,

                            'price' => $price,

                        ]);

                    }

                }

            }



            // Delete records with 'name' values that are not in the received data

            DB::table('quotation_items')

                ->where('quotation_id', $id)

                ->whereNotIn('name', $request->input('item'))

                ->delete();







            DB::commit(); // Everything went well, commit the changes



            return redirect()->back()->with('success', 'Quotation updated successfully.');



        } catch (\Exception $e) {

            DB::rollback(); // Something went wrong, rollback the changes



            // Log the error

            Log::error('Transaction failed: ' . $e->getMessage());

            dd($e->getMessage());

            // Handle the exception or error message

        }



    }





    public function charges(Request $request, $id)

    {

        //dd($request->all());



        $chargeIds = $request->input('charge_id');

        $charges = $request->input('charge');



        // Loop through the charges and update or delete as needed

        foreach ($chargeIds as $index => $chargeId) {

            $ifexists = DB::table('quotation_charges')->where('charge_id', $chargeId)->where('quotation_id', $id)->exists();

            $chargeValue = $charges[$index];

            // Check if the charge is zero

            if ($chargeValue == 0) {

                // Delete the row if the charge is zero



                DB::table('quotation_charges')->where('charge_id', $chargeId)->where('quotation_id', $id)->delete();

            } else {

                if ($ifexists) {

                    // Update the charge amount if it's not zero

                    DB::table('quotation_charges')->where('charge_id', $chargeId)->where('quotation_id', $id)->update(['amount' => $chargeValue]);

                } else {

                    DB::table('quotation_charges')->insert([

                        'charge_id' => $chargeId,

                        'quotation_id' => $id,

                        'amount' => $chargeValue

                    ]);

                }

            }



        }



        return redirect()->back()->with('success', 'Quotation updated successfully.');



    }





}

