<?php

namespace App\Http\Controllers;

use App\Http\Requests\StoreCustomerRequest;
use App\Http\Requests\UpdateCustomerRequest;

use Illuminate\Http\Request;
use App\Models\Vendor;
use App\Models\COA\SubAccount;
use App\Models\PurchaseInvoice;
use App\Facades\Company;
use App\Models\PayablePayment;
use Illuminate\Pagination\LengthAwarePaginator;

class VendorController extends Controller
{


    use \App\Http\Controllers\Traits\Functions;



    public function checkaoa($id)
    {
        return $this->sub_account_code(16);
    }

    public function index()
    {
        $vendors = Vendor::latest()->paginate(100);
        return view('vendors.index', ['vendors' => $vendors]);
    }
    public function create()
    {

        return view('vendors.create', [
            'vendor' => []
        ]);
    }


    public function store(Request $request)
    {


        $vendor = new Vendor();
        $vendor->email = $request->email;
        $vendor->name = $request->name;
        $vendor->company = $request->company;
        $vendor->website = $request->website;
        $vendor->phone = $request->phone;
        $vendor->company_id = auth()->user()->company_id;
        $vendor->isActive = 1;
        $vendor->save();


        $subaccount = new SubAccount();
        $subaccount->name = $request->company;
        $subaccount->related_type = 'App\Models\Vendor';
        $subaccount->code = $this->sub_account_code(16);
        $subaccount->related_id = $vendor->id;
        $subaccount->company_id = auth()->user()->company_id;
        $subaccount->coa_account_head_id = 16;
        $subaccount->reportLink = '/coa/vendor/' . $vendor->id;
        $subaccount->save();


        return redirect()->back()->with('success', 'Vendor created successfully.');

    }


    public function edit($id)
    {
        $vendor = Vendor::find($id);

        return view('vendors.edit', [
            'vendor' => $vendor
        ]);
    }

    // public function update(UpdateCustomerRequest $request, $id)
    // {
    //     $customer = Customer::findOrFail($id);
    //     $data = $request->validated();

    //     $customer->update($data);
    //     return redirect()->route('customers')->with('success', 'Customer updated successfully.');
    // }


    // public function userCustomers($id)
    // {

    //     $searchTerm = request()->input('searchQuery');
    //     $customers = Customer::select('id', 'company', 'email', 'firstName', 'lastName', 'address', 'city', 'state_id', 'postalCode', 'country_id', 'phone')
    //         //->where('user_id', $id)
    //         ->where('company', 'LIKE', '%' . $searchTerm . '%')
    //         ->where('company_id', \Auth::user()->company_id)
    //         ->limit(5)
    //         ->get();

    //     return response()->json($customers);
    // }

    public function companyVendors($company_id)
    {
        $vendors = Vendor::latest()
            ->where('company_id', $company_id)
            ->where('isActive', 1)
            ->get();
        return response()->json($vendors);

    }

        public function vendorLedger($id)
    {
        

        $vendor = Vendor::findOrfail($id);
      
        $purchaseInvoices = PurchaseInvoice::where('company_id', auth()->user()->company_id)->paginate(20);

      
        $payablePayments = PayablePayment::where('company_id', auth()->user()->company_id)->paginate(20);

      
        $combinedTransactions = $purchaseInvoices->merge($payablePayments);

        $sortedTransactions = $combinedTransactions->sortByDesc(function ($transaction) {
            return $transaction->invoicedate ?? $transaction->payment_date;
        });

        $currentPage = LengthAwarePaginator::resolveCurrentPage();
        $perPage = 20;
        $currentPageItems = $sortedTransactions->slice(($currentPage - 1) * $perPage, $perPage)->all();
        $transactionsPaginated = new LengthAwarePaginator($currentPageItems, count($sortedTransactions), $perPage, $currentPage);

    
        $company = Company::info();
        return view('vendors.report', ['transactions' => $transactionsPaginated, 'company' => $company, 'vendor' =>  $vendor]);

    }


}
