<?php



namespace App\Models;



use Illuminate\Support\Str;



use Illuminate\Database\Eloquent\Model;

use Spatie\Activitylog\Traits\LogsActivity;

use Spatie\Activitylog\LogOptions;





class Invoice extends Model

{



  //use LogsActivity;



  protected $fillable = ['*'];



  protected static $logAttributes = ['*'];







  protected $primaryKey = 'id'; // Specify primary key name

  public $incrementing = false; // UUIDs are not auto-incrementing



  protected static function boot()

  {

    parent::boot();



    static::creating(function ($model) {

      $model->id = Str::uuid(); // Generate UUID for primary key

    });

  }



  public function order()

  {

    return $this->belongsTo(Order::class, 'order_id')->select('saleorder_id', 'id', 'user_id', 'orderdate');

  }

  public function getActivitylogOptions(): LogOptions

  {

    return LogOptions::defaults();

  }





  public function payment()

  {

    return $this->belongsTo(PaymentGateway::class, 'payment_gateway_id')->select('name');

  }



  public function stateName()

  {

    return $this->belongsTo(State::class);

  }



  public function getStateInfo($stateId)

  {

    $state = State::select('name', 'code')->find($stateId);

    return $state;

  }



  public function saleRep()

  {

    return $this->belongsTo(User::class);

  }







  public function invoiceItems()

  {

    return $this->hasMany(InvoiceItem::class);

  }



  public function getTotalAmountSumAttribute()

  {

    return $this->invoiceItems->sum(function ($orderItem) {

      return $orderItem->quantity * $orderItem->price;

    });

  }



  public function invoicePayment()

  {



    return $this->hasMany(ReceivablePayment::class);

  }



  public function getTotalPaymentSumAttribute()

  {

    return $this->invoicePayment()->sum('amount');

  }



  public function getOptions($optionType)

  {

    $options = Alloption::select('id')->where(['optionType' => $optionType, 'company_id' => auth()->user()->company_id])->get();

    return $options;

  }

  public function invoiceShipping()

  {

    $idsArray = $this->getOptions('shipping');

    return $this->hasMany(InvoiceCharge::class)->whereIn('charge_id', $idsArray);

  }



  public function getTotalShippingSumAttribute()

  {

    return $this->invoiceShipping()->sum('amount');

  }

  public function invoiceTax()

  {

    $idsArray = $this->getOptions('tax');

    return $this->hasMany(InvoiceCharge::class)->whereIn('charge_id', $idsArray);

  }



  public function getTotalTaxSumAttribute()

  {

    return $this->invoiceTax()->sum('amount');

  }



  public function invoiceCreditCard()

  {

    $idsArray = $this->getOptions('cc');

    return $this->hasMany(InvoiceCharge::class)->whereIn('charge_id', $idsArray);

  }



  public function getTotalCreditCardSumAttribute()

  {

    return $this->invoiceCreditCard()->sum('amount');

  }


    public function invoiceGoodSold()

  {

    $idsArray = $this->getOptions('cc');

    return $this->hasMany(InvoiceCharge::class)->whereIn('charge_id', $idsArray);

  }



  public function getTotalGoodSoldSumAttribute()

  {

    return $this->invoiceCreditCard()->sum('amount');

  }

  public function invoiceCharges()

  {

    return $this->hasMany(InvoiceCharge::class);

  }



  public function getTotalChargeSumAttribute()

  {

    return $this->invoiceCharges()->sum('amount');

  }





  public function customer()

  {

    return $this->belongsTo(Customer::class);

  }



  public function company()

  {

    return $this->belongsTo(Company::class);

  }





  public function state()

  {

    return $this->belongsTo(State::class, 'shippingState_id');

  }



  public function country()

  {

    return $this->belongsTo(Country::class, 'shippingCountry_id');

  }





  public function parent()

  {

    return $this->belongsTo(Invoice::class, 'credit_note_invoice_id');

  }



  public function creditNotes()

  {

    return $this->hasMany(Invoice::class, 'credit_note_invoice_id');

  }



}

