<?php



namespace App\Models;



use Illuminate\Support\Str;



use Illuminate\Database\Eloquent\Model;

use Spatie\Activitylog\Traits\LogsActivity;

use Spatie\Activitylog\LogOptions;





class Order extends Model

{



  //use LogsActivity;



  protected $fillable = ['*'];



  //protected static $logAttributes = ['*'];



  protected $primaryKey = 'id'; // Specify primary key name

  public $incrementing = false; // UUIDs are not auto-incrementing



  protected static function boot()

  {

    parent::boot();



    static::creating(function ($model) {

      $model->id = Str::uuid(); // Generate UUID for primary key

    });

  }



  public function getActivitylogOptions(): LogOptions

  {

    return LogOptions::defaults();

  }



  public function stateName()

  {

    return $this->belongsTo(State::class);

  }





  public function payment()

  {

    return $this->belongsTo(Alloption::class, 'payment_id')->select('name');

  }

   public function gateway()
  {
    return $this->belongsTo(PaymentGateway::class, 'gateway_id')->select('name');
  }

  public function getStateInfo($stateId)

  {

    $state = State::select('name', 'code')->find($stateId);

    return $state;

  }



  public function saleRep()

  {

    return $this->belongsTo(UserInfo::class, 'user_id');

  }



  public function orderItems()

  {

    return $this->hasMany(OrderItem::class);

  }



  public function getTotalAmountSumAttribute()

  {

    return $this->orderItems->sum(function ($orderItem) {

      return $orderItem->quantity * $orderItem->price;

    });

  }



  public function purchaseItemPurchasedTillNow()

  {

    $totalCost = 0;



    // Retrieve all order items for this order

    $orderItems = $this->orderItems;



    foreach ($orderItems as $orderItem) {

      // Retrieve all purchase items for this order item

      $purchaseItems = $orderItem->purchaseItem;



      foreach ($purchaseItems as $purchaseItem) {

        // Retrieve the price from the corresponding order item

        $price = $orderItem->price;



        // Assuming each PurchaseItem has a quantity

        $totalCost += $purchaseItem->quantity * $price;

      }

    }



    return $totalCost;

  }







  public function orderCharges()

  {

    return $this->hasMany(OrderCharge::class);

  }



  public function getTotalChargeSumAttribute()

  {

    return $this->orderCharges()->sum('amount');

  }





  public function customer()

  {

    return $this->belongsTo(Customer::class);

  }

  public function company()

  {

    return $this->belongsTo(Company::class);

  }





  public function purchases()

  {

    return $this->hasMany(Purchase::class);

  }



  public function purchaseInvoices()

  {

    return $this->hasMany(PurchaseInvoice::class);

  }



  public function saleInvoices()

  {

    return $this->hasMany(Invoice::class);

  }

}

