<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Str;

class Purchase extends Model
{

  protected $primaryKey = 'id'; // Specify primary key name
  public $incrementing = false; // UUIDs are not auto-incrementing

  protected static function boot()
  {
    parent::boot();

    static::creating(function ($model) {
      $model->id = Str::uuid(); // Generate UUID for primary key
    });
  }


  public function vendor()
  {
    return $this->belongsTo(Vendor::class);
  }


  public function order()
  {
    return $this->belongsTo(Order::class, 'order_id')->select('saleorder_id', 'id');
  }

  public function getStateInfo($stateId)
  {
    $state = State::select('name', 'code')->find($stateId);
    return $state;
  }

  public function purchaseItems()
  {
    return $this->hasMany(PurchaseItem::class);
  }

  public function getTotalAmountSumAttribute()
  {
    return $this->purchaseItems->sum(function ($orderItem) {
      return $orderItem->quantity * $orderItem->price;
    });
  }


  public function purchaseCharges()
  {
    return $this->hasMany(PurchaseCharge::class);
  }

  public function getTotalChargeSumAttribute()
  {
    return $this->purchaseCharges()->sum('amount');
  }

  public function payment()
  {
    return $this->belongsTo(PaymentGateway::class, 'payment_id')->select('name');
  }

  public function customer()
  {
    return $this->belongsTo(Customer::class);
  }

  public function company()
  {
    return $this->belongsTo(Company::class);
  }
}
