<?php

namespace App\Models;

use Illuminate\Support\Str;

use Illuminate\Database\Eloquent\Model;
use Spatie\Activitylog\Traits\LogsActivity;
use Spatie\Activitylog\LogOptions;


class Quotation extends Model
{

  //use LogsActivity;

  protected $fillable = ['*'];

  //protected static $logAttributes = ['*'];

  protected $primaryKey = 'id'; // Specify primary key name
  public $incrementing = false; // UUIDs are not auto-incrementing

  protected static function boot()
  {
    parent::boot();

    static::creating(function ($model) {
      $model->id = Str::uuid(); // Generate UUID for primary key
    });
  }

  public function getActivitylogOptions(): LogOptions
  {
    return LogOptions::defaults();
  }

  public function stateName()
  {
    return $this->belongsTo(State::class);
  }


  public function payment()
  {
    return $this->belongsTo(Alloption::class, 'payment_id')->select('name');
  }

  public function getStateInfo($stateId)
  {
    $state = State::select('name', 'code')->find($stateId);
    return $state;
  }

  public function saleRep()
  {
    return $this->belongsTo(UserInfo::class, 'user_id');
  }

  public function quotationItems()
  {
    return $this->hasMany(QuotationItem::class);
  }

  public function getTotalAmountSumAttribute()
  {
    return $this->quotationItems->sum(function ($quotationItem) {
      return $quotationItem->quantity * $quotationItem->price;
    });
  }


  public function quotationCharges()
  {
    return $this->hasMany(QuotationCharge::class);
  }

  public function getTotalChargeSumAttribute()
  {
    return $this->quotationCharges()->sum('amount');
  }


  public function customer()
  {
    return $this->belongsTo(Customer::class);
  }

  public function company()
  {
    return $this->belongsTo(Company::class);
  }
}
